@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="api_client.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -77,12 +77,12 @@ class ApiClient(object):
 
         self.pool = ThreadPool()
         self.rest_client = rest.RESTClientObject(configuration)
-        self.default_headers = {'x-aspose-client': 'python sdk', 'x-aspose-version': '20.5'}
+        self.default_headers = {'x-aspose-client': 'python sdk', 'x-aspose-version': '20.6'}
         if header_name is not None:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'python sdk 20.5'
+        self.user_agent = 'python sdk 20.6'
 
     def __del__(self):
         self.pool.close()
@@ -101,6 +101,50 @@ class ApiClient(object):
         """Setting default header"""
         self.default_headers[header_name] = header_value
 
+    def request_token(self):
+        config = self.configuration
+        request_url = "/connect/token"
+        form_params = [['grant_type', 'client_credentials', 'string'],
+                       ['client_id', config.api_key['app_sid'], 'string'],
+                       ['client_secret', config.api_key['api_key'], 'string']]
+
+        header_params = {'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}
+
+        if self.cookie:
+            header_params['Cookie'] = self.cookie
+        if header_params:
+            header_params = self.sanitize_for_serialization(header_params)
+            header_params = dict(self.parameters_to_tuples(header_params,
+                                                           {}))
+
+        # remove optional path parameters
+        resource_path = request_url.replace('//', '/')
+
+        # post parameters
+        if form_params:
+            form_params = self.prepare_post_parameters(form_params)
+            form_params = self.sanitize_for_serialization(form_params)
+            form_params = self.parameters_to_tuples(form_params,
+                                                    {})
+
+        # request url
+        url = ''
+        if six.PY3:
+            url = self.configuration.host + resource_path
+        else:
+            url = (self.configuration.host + resource_path).encode('utf8')
+
+        # perform request and return response
+        response_data = self.request(
+            'POST', url, query_params=[], headers=header_params,
+            post_params=form_params, body=None,
+            _preload_content=True,
+            _request_timeout=None)
+
+        return_data = self.deserialize(response_data, 'object')
+        access_token = return_data['access_token'] if six.PY3 else return_data['access_token'].encode('utf8')
+        self.configuration.access_token = access_token
+
     def __call_api(
             self, resource_path, method, path_params=None,
             query_params=None, header_params=None, body=None, post_params=None,
@@ -110,6 +154,9 @@ class ApiClient(object):
         """Call api method"""
         config = self.configuration
 
+        if config.access_token is None or config.access_token == "":
+            self.request_token()
+
         # header parameters
         header_params = header_params or {}
         header_params.update(self.default_headers)
@@ -132,7 +179,7 @@ class ApiClient(object):
                     '{%s}' % k,
                     quote(str(v), safe=config.safe_chars_for_path_param)
                 )
-				
+
         # remove optional path parameters
         resource_path = resource_path.replace('//', '/')
 
@@ -616,7 +663,7 @@ class ApiClient(object):
         """
         if klass is None: 
             return data
-            
+
         if not klass.swagger_types and not hasattr(klass,
                                                    'get_real_child_model'):
             return data
