@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="ApiError.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="api_error.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -42,40 +42,40 @@ class ApiError(object):
     """
     swagger_types = {
         'code': 'str',
-        'message': 'str',
-        'description': 'str',
         'date_time': 'datetime',
-        'inner_error': 'ApiError'
+        'description': 'str',
+        'inner_error': 'ApiError',
+        'message': 'str'
     }
 
     attribute_map = {
         'code': 'Code',
-        'message': 'Message',
-        'description': 'Description',
         'date_time': 'DateTime',
-        'inner_error': 'InnerError'
+        'description': 'Description',
+        'inner_error': 'InnerError',
+        'message': 'Message'
     }
 
-    def __init__(self, code=None, message=None, description=None, date_time=None, inner_error=None):  # noqa: E501
+    def __init__(self, code=None, date_time=None, description=None, inner_error=None, message=None):  # noqa: E501
         """ApiError - a model defined in Swagger"""  # noqa: E501
 
         self._code = None
-        self._message = None
-        self._description = None
         self._date_time = None
+        self._description = None
         self._inner_error = None
+        self._message = None
         self.discriminator = None
 
         if code is not None:
             self.code = code
-        if message is not None:
-            self.message = message
-        if description is not None:
-            self.description = description
         if date_time is not None:
             self.date_time = date_time
+        if description is not None:
+            self.description = description
         if inner_error is not None:
             self.inner_error = inner_error
+        if message is not None:
+            self.message = message
 
     @property
     def code(self):
@@ -98,48 +98,7 @@ class ApiError(object):
         :type: str
         """
         self._code = code
-    @property
-    def message(self):
-        """Gets the message of this ApiError.  # noqa: E501
 
-        Gets or sets error message.  # noqa: E501
-
-        :return: The message of this ApiError.  # noqa: E501
-        :rtype: str
-        """
-        return self._message
-
-    @message.setter
-    def message(self, message):
-        """Sets the message of this ApiError.
-
-        Gets or sets error message.  # noqa: E501
-
-        :param message: The message of this ApiError.  # noqa: E501
-        :type: str
-        """
-        self._message = message
-    @property
-    def description(self):
-        """Gets the description of this ApiError.  # noqa: E501
-
-        Gets or sets error description.  # noqa: E501
-
-        :return: The description of this ApiError.  # noqa: E501
-        :rtype: str
-        """
-        return self._description
-
-    @description.setter
-    def description(self, description):
-        """Sets the description of this ApiError.
-
-        Gets or sets error description.  # noqa: E501
-
-        :param description: The description of this ApiError.  # noqa: E501
-        :type: str
-        """
-        self._description = description
     @property
     def date_time(self):
         """Gets the date_time of this ApiError.  # noqa: E501
@@ -161,11 +120,34 @@ class ApiError(object):
         :type: datetime
         """
         self._date_time = date_time
+
+    @property
+    def description(self):
+        """Gets the description of this ApiError.  # noqa: E501
+
+        Gets or sets error description.  # noqa: E501
+
+        :return: The description of this ApiError.  # noqa: E501
+        :rtype: str
+        """
+        return self._description
+
+    @description.setter
+    def description(self, description):
+        """Sets the description of this ApiError.
+
+        Gets or sets error description.  # noqa: E501
+
+        :param description: The description of this ApiError.  # noqa: E501
+        :type: str
+        """
+        self._description = description
+
     @property
     def inner_error(self):
         """Gets the inner_error of this ApiError.  # noqa: E501
 
-        Gets or sets inner_error.  # noqa: E501
+        Gets or sets inner error.  # noqa: E501
 
         :return: The inner_error of this ApiError.  # noqa: E501
         :rtype: ApiError
@@ -176,12 +158,36 @@ class ApiError(object):
     def inner_error(self, inner_error):
         """Sets the inner_error of this ApiError.
 
-        Gets or sets inner_error.  # noqa: E501
+        Gets or sets inner error.  # noqa: E501
 
         :param inner_error: The inner_error of this ApiError.  # noqa: E501
         :type: ApiError
         """
         self._inner_error = inner_error
+
+    @property
+    def message(self):
+        """Gets the message of this ApiError.  # noqa: E501
+
+        Gets or sets error message.  # noqa: E501
+
+        :return: The message of this ApiError.  # noqa: E501
+        :rtype: str
+        """
+        return self._message
+
+    @message.setter
+    def message(self, message):
+        """Sets the message of this ApiError.
+
+        Gets or sets error message.  # noqa: E501
+
+        :param message: The message of this ApiError.  # noqa: E501
+        :type: str
+        """
+        self._message = message
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -223,4 +229,4 @@ class ApiError(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
