@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Bookmark.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="bookmark.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -47,7 +47,7 @@ class Bookmark(object):
     }
 
     attribute_map = {
-        'link': 'link',
+        'link': 'Link',
         'name': 'Name',
         'text': 'Text'
     }
@@ -71,7 +71,7 @@ class Bookmark(object):
     def link(self):
         """Gets the link of this Bookmark.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this Bookmark.  # noqa: E501
         :rtype: WordsApiLink
@@ -82,12 +82,13 @@ class Bookmark(object):
     def link(self, link):
         """Sets the link of this Bookmark.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this Bookmark.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
     @property
     def name(self):
         """Gets the name of this Bookmark.  # noqa: E501
@@ -109,6 +110,7 @@ class Bookmark(object):
         :type: str
         """
         self._name = name
+
     @property
     def text(self):
         """Gets the text of this Bookmark.  # noqa: E501
@@ -130,6 +132,8 @@ class Bookmark(object):
         :type: str
         """
         self._text = text
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -171,4 +175,4 @@ class Bookmark(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
