@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="BordersResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="borders_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,11 +83,12 @@ class BordersResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def borders(self):
         """Gets the borders of this BordersResponse.  # noqa: E501
 
-        Gets or sets borders.  # noqa: E501
+        Gets or sets table.  # noqa: E501
 
         :return: The borders of this BordersResponse.  # noqa: E501
         :rtype: BordersCollection
@@ -98,12 +99,14 @@ class BordersResponse(object):
     def borders(self, borders):
         """Sets the borders of this BordersResponse.
 
-        Gets or sets borders.  # noqa: E501
+        Gets or sets table.  # noqa: E501
 
         :param borders: The borders of this BordersResponse.  # noqa: E501
         :type: BordersCollection
         """
         self._borders = borders
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class BordersResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
