@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Comment.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="comment.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -52,7 +52,7 @@ class Comment(object):
     }
 
     attribute_map = {
-        'link': 'link',
+        'link': 'Link',
         'author': 'Author',
         'content': 'Content',
         'date_time': 'DateTime',
@@ -96,7 +96,7 @@ class Comment(object):
     def link(self):
         """Gets the link of this Comment.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this Comment.  # noqa: E501
         :rtype: WordsApiLink
@@ -107,12 +107,13 @@ class Comment(object):
     def link(self, link):
         """Sets the link of this Comment.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this Comment.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
     @property
     def author(self):
         """Gets the author of this Comment.  # noqa: E501
@@ -134,11 +135,12 @@ class Comment(object):
         :type: str
         """
         self._author = author
+
     @property
     def content(self):
         """Gets the content of this Comment.  # noqa: E501
 
-        Gets or sets content.  # noqa: E501
+        Gets or sets content of comment.  # noqa: E501
 
         :return: The content of this Comment.  # noqa: E501
         :rtype: StoryChildNodes
@@ -149,12 +151,13 @@ class Comment(object):
     def content(self, content):
         """Sets the content of this Comment.
 
-        Gets or sets content.  # noqa: E501
+        Gets or sets content of comment.  # noqa: E501
 
         :param content: The content of this Comment.  # noqa: E501
         :type: StoryChildNodes
         """
         self._content = content
+
     @property
     def date_time(self):
         """Gets the date_time of this Comment.  # noqa: E501
@@ -176,6 +179,7 @@ class Comment(object):
         :type: datetime
         """
         self._date_time = date_time
+
     @property
     def initial(self):
         """Gets the initial of this Comment.  # noqa: E501
@@ -197,11 +201,12 @@ class Comment(object):
         :type: str
         """
         self._initial = initial
+
     @property
     def range_end(self):
         """Gets the range_end of this Comment.  # noqa: E501
 
-        Gets or sets range_end.  # noqa: E501
+        Gets or sets link to comment range end node.  # noqa: E501
 
         :return: The range_end of this Comment.  # noqa: E501
         :rtype: DocumentPosition
@@ -212,17 +217,18 @@ class Comment(object):
     def range_end(self, range_end):
         """Sets the range_end of this Comment.
 
-        Gets or sets range_end.  # noqa: E501
+        Gets or sets link to comment range end node.  # noqa: E501
 
         :param range_end: The range_end of this Comment.  # noqa: E501
         :type: DocumentPosition
         """
         self._range_end = range_end
+
     @property
     def range_start(self):
         """Gets the range_start of this Comment.  # noqa: E501
 
-        Gets or sets range_start.  # noqa: E501
+        Gets or sets link to comment range start node.  # noqa: E501
 
         :return: The range_start of this Comment.  # noqa: E501
         :rtype: DocumentPosition
@@ -233,12 +239,13 @@ class Comment(object):
     def range_start(self, range_start):
         """Sets the range_start of this Comment.
 
-        Gets or sets range_start.  # noqa: E501
+        Gets or sets link to comment range start node.  # noqa: E501
 
         :param range_start: The range_start of this Comment.  # noqa: E501
         :type: DocumentPosition
         """
         self._range_start = range_start
+
     @property
     def text(self):
         """Gets the text of this Comment.  # noqa: E501
@@ -260,6 +267,8 @@ class Comment(object):
         :type: str
         """
         self._text = text
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -301,4 +310,4 @@ class Comment(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
