@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="CommentLink.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="comment_link.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -45,7 +45,7 @@ class CommentLink(object):
     }
 
     attribute_map = {
-        'link': 'link'
+        'link': 'Link'
     }
 
     def __init__(self, link=None):  # noqa: E501
@@ -61,7 +61,7 @@ class CommentLink(object):
     def link(self):
         """Gets the link of this CommentLink.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this CommentLink.  # noqa: E501
         :rtype: WordsApiLink
@@ -72,12 +72,14 @@ class CommentLink(object):
     def link(self, link):
         """Sets the link of this CommentLink.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this CommentLink.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -119,4 +121,4 @@ class CommentLink(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
