@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="CommentsResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="comments_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,11 +83,12 @@ class CommentsResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def comments(self):
         """Gets the comments of this CommentsResponse.  # noqa: E501
 
-        Gets or sets comments.  # noqa: E501
+        Gets or sets collection of comments.  # noqa: E501
 
         :return: The comments of this CommentsResponse.  # noqa: E501
         :rtype: CommentsCollection
@@ -98,12 +99,14 @@ class CommentsResponse(object):
     def comments(self, comments):
         """Sets the comments of this CommentsResponse.
 
-        Gets or sets comments.  # noqa: E501
+        Gets or sets collection of comments.  # noqa: E501
 
         :param comments: The comments of this CommentsResponse.  # noqa: E501
         :type: CommentsCollection
         """
         self._comments = comments
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class CommentsResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
