@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="DocSaveOptionsData.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="doc_save_options_data.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,16 +41,16 @@ class DocSaveOptionsData(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'save_format': 'str',
-        'file_name': 'str',
-        'dml_rendering_mode': 'str',
+        'dml3_d_effects_rendering_mode': 'str',
         'dml_effects_rendering_mode': 'str',
-        'zip_output': 'bool',
+        'dml_rendering_mode': 'str',
+        'file_name': 'str',
+        'save_format': 'str',
+        'update_fields': 'bool',
+        'update_last_printed_property': 'bool',
         'update_last_saved_time_property': 'bool',
         'update_sdt_content': 'bool',
-        'update_fields': 'bool',
-        'dml3_d_effects_rendering_mode': 'str',
-        'update_last_printed_property': 'bool',
+        'zip_output': 'bool',
         'always_compress_metafiles': 'bool',
         'password': 'str',
         'save_picture_bullet': 'bool',
@@ -58,61 +58,61 @@ class DocSaveOptionsData(object):
     }
 
     attribute_map = {
-        'save_format': 'SaveFormat',
-        'file_name': 'FileName',
-        'dml_rendering_mode': 'DmlRenderingMode',
+        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
         'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
-        'zip_output': 'ZipOutput',
+        'dml_rendering_mode': 'DmlRenderingMode',
+        'file_name': 'FileName',
+        'save_format': 'SaveFormat',
+        'update_fields': 'UpdateFields',
+        'update_last_printed_property': 'UpdateLastPrintedProperty',
         'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
         'update_sdt_content': 'UpdateSdtContent',
-        'update_fields': 'UpdateFields',
-        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
-        'update_last_printed_property': 'UpdateLastPrintedProperty',
+        'zip_output': 'ZipOutput',
         'always_compress_metafiles': 'AlwaysCompressMetafiles',
         'password': 'Password',
         'save_picture_bullet': 'SavePictureBullet',
         'save_routing_slip': 'SaveRoutingSlip'
     }
 
-    def __init__(self, save_format=None, file_name=None, dml_rendering_mode=None, dml_effects_rendering_mode=None, zip_output=None, update_last_saved_time_property=None, update_sdt_content=None, update_fields=None, dml3_d_effects_rendering_mode=None, update_last_printed_property=None, always_compress_metafiles=None, password=None, save_picture_bullet=None, save_routing_slip=None):  # noqa: E501
+    def __init__(self, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, always_compress_metafiles=None, password=None, save_picture_bullet=None, save_routing_slip=None):  # noqa: E501
         """DocSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
-        self._save_format = None
-        self._file_name = None
-        self._dml_rendering_mode = None
+        self._dml3_d_effects_rendering_mode = None
         self._dml_effects_rendering_mode = None
-        self._zip_output = None
+        self._dml_rendering_mode = None
+        self._file_name = None
+        self._save_format = None
+        self._update_fields = None
+        self._update_last_printed_property = None
         self._update_last_saved_time_property = None
         self._update_sdt_content = None
-        self._update_fields = None
-        self._dml3_d_effects_rendering_mode = None
-        self._update_last_printed_property = None
+        self._zip_output = None
         self._always_compress_metafiles = None
         self._password = None
         self._save_picture_bullet = None
         self._save_routing_slip = None
         self.discriminator = None
 
-        if save_format is not None:
-            self.save_format = save_format
-        if file_name is not None:
-            self.file_name = file_name
-        if dml_rendering_mode is not None:
-            self.dml_rendering_mode = dml_rendering_mode
+        if dml3_d_effects_rendering_mode is not None:
+            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
         if dml_effects_rendering_mode is not None:
             self.dml_effects_rendering_mode = dml_effects_rendering_mode
-        if zip_output is not None:
-            self.zip_output = zip_output
+        if dml_rendering_mode is not None:
+            self.dml_rendering_mode = dml_rendering_mode
+        if file_name is not None:
+            self.file_name = file_name
+        if save_format is not None:
+            self.save_format = save_format
+        if update_fields is not None:
+            self.update_fields = update_fields
+        if update_last_printed_property is not None:
+            self.update_last_printed_property = update_last_printed_property
         if update_last_saved_time_property is not None:
             self.update_last_saved_time_property = update_last_saved_time_property
         if update_sdt_content is not None:
             self.update_sdt_content = update_sdt_content
-        if update_fields is not None:
-            self.update_fields = update_fields
-        if dml3_d_effects_rendering_mode is not None:
-            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        if update_last_printed_property is not None:
-            self.update_last_printed_property = update_last_printed_property
+        if zip_output is not None:
+            self.zip_output = zip_output
         if always_compress_metafiles is not None:
             self.always_compress_metafiles = always_compress_metafiles
         if password is not None:
@@ -122,6 +122,102 @@ class DocSaveOptionsData(object):
         if save_routing_slip is not None:
             self.save_routing_slip = save_routing_slip
 
+    @property
+    def dml3_d_effects_rendering_mode(self):
+        """Gets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :return: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml3_d_effects_rendering_mode
+
+    @dml3_d_effects_rendering_mode.setter
+    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
+        """Sets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Basic", "Advanced"]  # noqa: E501
+        if not dml3_d_effects_rendering_mode.isdigit():
+            if dml3_d_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml3_d_effects_rendering_mode, allowed_values))
+            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        else:
+            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
+
+    @property
+    def dml_effects_rendering_mode(self):
+        """Gets the dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :return: The dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_effects_rendering_mode
+
+    @dml_effects_rendering_mode.setter
+    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
+        """Sets the dml_effects_rendering_mode of this DocSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+
+    @property
+    def dml_rendering_mode(self):
+        """Gets the dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :return: The dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_rendering_mode
+
+    @dml_rendering_mode.setter
+    def dml_rendering_mode(self, dml_rendering_mode):
+        """Sets the dml_rendering_mode of this DocSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :param dml_rendering_mode: The dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_rendering_mode = dml_rendering_mode
+
+    @property
+    def file_name(self):
+        """Gets the file_name of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :return: The file_name of this DocSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._file_name
+
+    @file_name.setter
+    def file_name(self, file_name):
+        """Sets the file_name of this DocSaveOptionsData.
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :param file_name: The file_name of this DocSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._file_name = file_name
+
     @property
     def save_format(self):
         """Gets the save_format of this DocSaveOptionsData.  # noqa: E501
@@ -143,137 +239,12 @@ class DocSaveOptionsData(object):
         :type: str
         """
         self._save_format = save_format
-    @property
-    def file_name(self):
-        """Gets the file_name of this DocSaveOptionsData.  # noqa: E501
 
-        Gets or sets name of destination file.  # noqa: E501
-
-        :return: The file_name of this DocSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._file_name
-
-    @file_name.setter
-    def file_name(self, file_name):
-        """Sets the file_name of this DocSaveOptionsData.
-
-        Gets or sets name of destination file.  # noqa: E501
-
-        :param file_name: The file_name of this DocSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._file_name = file_name
-    @property
-    def dml_rendering_mode(self):
-        """Gets the dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :return: The dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_rendering_mode
-
-    @dml_rendering_mode.setter
-    def dml_rendering_mode(self, dml_rendering_mode):
-        """Sets the dml_rendering_mode of this DocSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :param dml_rendering_mode: The dml_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_rendering_mode = dml_rendering_mode
-    @property
-    def dml_effects_rendering_mode(self):
-        """Gets the dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :return: The dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_effects_rendering_mode
-
-    @dml_effects_rendering_mode.setter
-    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
-        """Sets the dml_effects_rendering_mode of this DocSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
-    @property
-    def zip_output(self):
-        """Gets the zip_output of this DocSaveOptionsData.  # noqa: E501
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :return: The zip_output of this DocSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._zip_output
-
-    @zip_output.setter
-    def zip_output(self, zip_output):
-        """Sets the zip_output of this DocSaveOptionsData.
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :param zip_output: The zip_output of this DocSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._zip_output = zip_output
-    @property
-    def update_last_saved_time_property(self):
-        """Gets the update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :return: The update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_last_saved_time_property
-
-    @update_last_saved_time_property.setter
-    def update_last_saved_time_property(self, update_last_saved_time_property):
-        """Sets the update_last_saved_time_property of this DocSaveOptionsData.
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :param update_last_saved_time_property: The update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_last_saved_time_property = update_last_saved_time_property
-    @property
-    def update_sdt_content(self):
-        """Gets the update_sdt_content of this DocSaveOptionsData.  # noqa: E501
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :return: The update_sdt_content of this DocSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_sdt_content
-
-    @update_sdt_content.setter
-    def update_sdt_content(self, update_sdt_content):
-        """Sets the update_sdt_content of this DocSaveOptionsData.
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :param update_sdt_content: The update_sdt_content of this DocSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_sdt_content = update_sdt_content
     @property
     def update_fields(self):
         """Gets the update_fields of this DocSaveOptionsData.  # noqa: E501
 
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
 
         :return: The update_fields of this DocSaveOptionsData.  # noqa: E501
         :rtype: bool
@@ -284,41 +255,13 @@ class DocSaveOptionsData(object):
     def update_fields(self, update_fields):
         """Sets the update_fields of this DocSaveOptionsData.
 
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
 
         :param update_fields: The update_fields of this DocSaveOptionsData.  # noqa: E501
         :type: bool
         """
         self._update_fields = update_fields
-    @property
-    def dml3_d_effects_rendering_mode(self):
-        """Gets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
 
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :return: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml3_d_effects_rendering_mode
-
-    @dml3_d_effects_rendering_mode.setter
-    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
-        """Sets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.
-
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Basic", "Advanced"]  # noqa: E501
-        if not dml3_d_effects_rendering_mode.isdigit():	
-            if dml3_d_effects_rendering_mode not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
-                    .format(dml3_d_effects_rendering_mode, allowed_values))
-            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        else:
-            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
     @property
     def update_last_printed_property(self):
         """Gets the update_last_printed_property of this DocSaveOptionsData.  # noqa: E501
@@ -340,6 +283,73 @@ class DocSaveOptionsData(object):
         :type: bool
         """
         self._update_last_printed_property = update_last_printed_property
+
+    @property
+    def update_last_saved_time_property(self):
+        """Gets the update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :return: The update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_last_saved_time_property
+
+    @update_last_saved_time_property.setter
+    def update_last_saved_time_property(self, update_last_saved_time_property):
+        """Sets the update_last_saved_time_property of this DocSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :param update_last_saved_time_property: The update_last_saved_time_property of this DocSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_last_saved_time_property = update_last_saved_time_property
+
+    @property
+    def update_sdt_content(self):
+        """Gets the update_sdt_content of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :return: The update_sdt_content of this DocSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_sdt_content
+
+    @update_sdt_content.setter
+    def update_sdt_content(self, update_sdt_content):
+        """Sets the update_sdt_content of this DocSaveOptionsData.
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :param update_sdt_content: The update_sdt_content of this DocSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_sdt_content = update_sdt_content
+
+    @property
+    def zip_output(self):
+        """Gets the zip_output of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :return: The zip_output of this DocSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._zip_output
+
+    @zip_output.setter
+    def zip_output(self, zip_output):
+        """Sets the zip_output of this DocSaveOptionsData.
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :param zip_output: The zip_output of this DocSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._zip_output = zip_output
+
     @property
     def always_compress_metafiles(self):
         """Gets the always_compress_metafiles of this DocSaveOptionsData.  # noqa: E501
@@ -361,6 +371,7 @@ class DocSaveOptionsData(object):
         :type: bool
         """
         self._always_compress_metafiles = always_compress_metafiles
+
     @property
     def password(self):
         """Gets the password of this DocSaveOptionsData.  # noqa: E501
@@ -382,6 +393,7 @@ class DocSaveOptionsData(object):
         :type: str
         """
         self._password = password
+
     @property
     def save_picture_bullet(self):
         """Gets the save_picture_bullet of this DocSaveOptionsData.  # noqa: E501
@@ -403,6 +415,7 @@ class DocSaveOptionsData(object):
         :type: bool
         """
         self._save_picture_bullet = save_picture_bullet
+
     @property
     def save_routing_slip(self):
         """Gets the save_routing_slip of this DocSaveOptionsData.  # noqa: E501
@@ -424,6 +437,8 @@ class DocSaveOptionsData(object):
         :type: bool
         """
         self._save_routing_slip = save_routing_slip
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -465,4 +480,4 @@ class DocSaveOptionsData(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
