@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Document.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="document.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,46 +41,134 @@ class Document(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'links': 'list[Link]',
+        'document_properties': 'DocumentProperties',
         'file_name': 'str',
-        'source_format': 'str',
         'is_encrypted': 'bool',
         'is_signed': 'bool',
-        'document_properties': 'DocumentProperties'
+        'links': 'list[Link]',
+        'source_format': 'str'
     }
 
     attribute_map = {
-        'links': 'Links',
+        'document_properties': 'DocumentProperties',
         'file_name': 'FileName',
-        'source_format': 'SourceFormat',
         'is_encrypted': 'IsEncrypted',
         'is_signed': 'IsSigned',
-        'document_properties': 'DocumentProperties'
+        'links': 'Links',
+        'source_format': 'SourceFormat'
     }
 
-    def __init__(self, links=None, file_name=None, source_format=None, is_encrypted=None, is_signed=None, document_properties=None):  # noqa: E501
+    def __init__(self, document_properties=None, file_name=None, is_encrypted=None, is_signed=None, links=None, source_format=None):  # noqa: E501
         """Document - a model defined in Swagger"""  # noqa: E501
 
-        self._links = None
+        self._document_properties = None
         self._file_name = None
-        self._source_format = None
         self._is_encrypted = None
         self._is_signed = None
-        self._document_properties = None
+        self._links = None
+        self._source_format = None
         self.discriminator = None
 
-        if links is not None:
-            self.links = links
+        if document_properties is not None:
+            self.document_properties = document_properties
         if file_name is not None:
             self.file_name = file_name
-        if source_format is not None:
-            self.source_format = source_format
         if is_encrypted is not None:
             self.is_encrypted = is_encrypted
         if is_signed is not None:
             self.is_signed = is_signed
-        if document_properties is not None:
-            self.document_properties = document_properties
+        if links is not None:
+            self.links = links
+        if source_format is not None:
+            self.source_format = source_format
+
+    @property
+    def document_properties(self):
+        """Gets the document_properties of this Document.  # noqa: E501
+
+        Gets or sets returns document properties.  # noqa: E501
+
+        :return: The document_properties of this Document.  # noqa: E501
+        :rtype: DocumentProperties
+        """
+        return self._document_properties
+
+    @document_properties.setter
+    def document_properties(self, document_properties):
+        """Sets the document_properties of this Document.
+
+        Gets or sets returns document properties.  # noqa: E501
+
+        :param document_properties: The document_properties of this Document.  # noqa: E501
+        :type: DocumentProperties
+        """
+        self._document_properties = document_properties
+
+    @property
+    def file_name(self):
+        """Gets the file_name of this Document.  # noqa: E501
+
+        Gets or sets the name of the file.  # noqa: E501
+
+        :return: The file_name of this Document.  # noqa: E501
+        :rtype: str
+        """
+        return self._file_name
+
+    @file_name.setter
+    def file_name(self, file_name):
+        """Sets the file_name of this Document.
+
+        Gets or sets the name of the file.  # noqa: E501
+
+        :param file_name: The file_name of this Document.  # noqa: E501
+        :type: str
+        """
+        self._file_name = file_name
+
+    @property
+    def is_encrypted(self):
+        """Gets the is_encrypted of this Document.  # noqa: E501
+
+        Gets or sets a value indicating whether returns true if the document is encrypted and requires a password to open.  # noqa: E501
+
+        :return: The is_encrypted of this Document.  # noqa: E501
+        :rtype: bool
+        """
+        return self._is_encrypted
+
+    @is_encrypted.setter
+    def is_encrypted(self, is_encrypted):
+        """Sets the is_encrypted of this Document.
+
+        Gets or sets a value indicating whether returns true if the document is encrypted and requires a password to open.  # noqa: E501
+
+        :param is_encrypted: The is_encrypted of this Document.  # noqa: E501
+        :type: bool
+        """
+        self._is_encrypted = is_encrypted
+
+    @property
+    def is_signed(self):
+        """Gets the is_signed of this Document.  # noqa: E501
+
+        Gets or sets a value indicating whether returns true if the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501
+
+        :return: The is_signed of this Document.  # noqa: E501
+        :rtype: bool
+        """
+        return self._is_signed
+
+    @is_signed.setter
+    def is_signed(self, is_signed):
+        """Sets the is_signed of this Document.
+
+        Gets or sets a value indicating whether returns true if the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501
+
+        :param is_signed: The is_signed of this Document.  # noqa: E501
+        :type: bool
+        """
+        self._is_signed = is_signed
 
     @property
     def links(self):
@@ -103,27 +191,7 @@ class Document(object):
         :type: list[Link]
         """
         self._links = links
-    @property
-    def file_name(self):
-        """Gets the file_name of this Document.  # noqa: E501
 
-        Gets or sets the name of the file.  # noqa: E501
-
-        :return: The file_name of this Document.  # noqa: E501
-        :rtype: str
-        """
-        return self._file_name
-
-    @file_name.setter
-    def file_name(self, file_name):
-        """Sets the file_name of this Document.
-
-        Gets or sets the name of the file.  # noqa: E501
-
-        :param file_name: The file_name of this Document.  # noqa: E501
-        :type: str
-        """
-        self._file_name = file_name
     @property
     def source_format(self):
         """Gets the source_format of this Document.  # noqa: E501
@@ -145,7 +213,7 @@ class Document(object):
         :type: str
         """
         allowed_values = ["Unknown", "Doc", "Dot", "DocPreWord60", "Docx", "Docm", "Dotx", "Dotm", "FlatOpc", "Rtf", "WordML", "Html", "Mhtml", "Epub", "Text", "Odt", "Ott", "Pdf", "Xps", "Tiff", "Svg"]  # noqa: E501
-        if not source_format.isdigit():	
+        if not source_format.isdigit():
             if source_format not in allowed_values:
                 raise ValueError(
                     "Invalid value for `source_format` ({0}), must be one of {1}"  # noqa: E501
@@ -153,69 +221,8 @@ class Document(object):
             self._source_format = source_format
         else:
             self._source_format = allowed_values[int(source_format) if six.PY3 else long(source_format)]
-    @property
-    def is_encrypted(self):
-        """Gets the is_encrypted of this Document.  # noqa: E501
 
-        Gets or sets a value indicating whether returns true if the document is encrypted and requires a password to open.  # noqa: E501
 
-        :return: The is_encrypted of this Document.  # noqa: E501
-        :rtype: bool
-        """
-        return self._is_encrypted
-
-    @is_encrypted.setter
-    def is_encrypted(self, is_encrypted):
-        """Sets the is_encrypted of this Document.
-
-        Gets or sets a value indicating whether returns true if the document is encrypted and requires a password to open.  # noqa: E501
-
-        :param is_encrypted: The is_encrypted of this Document.  # noqa: E501
-        :type: bool
-        """
-        self._is_encrypted = is_encrypted
-    @property
-    def is_signed(self):
-        """Gets the is_signed of this Document.  # noqa: E501
-
-        Gets or sets a value indicating whether returns true if the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501
-
-        :return: The is_signed of this Document.  # noqa: E501
-        :rtype: bool
-        """
-        return self._is_signed
-
-    @is_signed.setter
-    def is_signed(self, is_signed):
-        """Sets the is_signed of this Document.
-
-        Gets or sets a value indicating whether returns true if the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501
-
-        :param is_signed: The is_signed of this Document.  # noqa: E501
-        :type: bool
-        """
-        self._is_signed = is_signed
-    @property
-    def document_properties(self):
-        """Gets the document_properties of this Document.  # noqa: E501
-
-        Gets or sets document_properties.  # noqa: E501
-
-        :return: The document_properties of this Document.  # noqa: E501
-        :rtype: DocumentProperties
-        """
-        return self._document_properties
-
-    @document_properties.setter
-    def document_properties(self, document_properties):
-        """Sets the document_properties of this Document.
-
-        Gets or sets document_properties.  # noqa: E501
-
-        :param document_properties: The document_properties of this Document.  # noqa: E501
-        :type: DocumentProperties
-        """
-        self._document_properties = document_properties
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -257,4 +264,4 @@ class Document(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
