@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="DrawingObjectResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="drawing_object_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -30,7 +30,7 @@ import six
 
 
 class DrawingObjectResponse(object):
-    """Response for \&quot;drawingObjects/n\&quot; resource.
+    """Response for "drawingObjects/n" resource.
     """
 
     """
@@ -83,11 +83,12 @@ class DrawingObjectResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def drawing_object(self):
         """Gets the drawing_object of this DrawingObjectResponse.  # noqa: E501
 
-        Gets or sets drawing_object.  # noqa: E501
+        Gets or sets drawing object.  # noqa: E501
 
         :return: The drawing_object of this DrawingObjectResponse.  # noqa: E501
         :rtype: DrawingObject
@@ -98,12 +99,14 @@ class DrawingObjectResponse(object):
     def drawing_object(self, drawing_object):
         """Sets the drawing_object of this DrawingObjectResponse.
 
-        Gets or sets drawing_object.  # noqa: E501
+        Gets or sets drawing object.  # noqa: E501
 
         :param drawing_object: The drawing_object of this DrawingObjectResponse.  # noqa: E501
         :type: DrawingObject
         """
         self._drawing_object = drawing_object
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class DrawingObjectResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
