@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="DrawingObjectsResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="drawing_objects_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,11 +83,12 @@ class DrawingObjectsResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def drawing_objects(self):
         """Gets the drawing_objects of this DrawingObjectsResponse.  # noqa: E501
 
-        Gets or sets drawing_objects.  # noqa: E501
+        Gets or sets collection of drawing objects.  # noqa: E501
 
         :return: The drawing_objects of this DrawingObjectsResponse.  # noqa: E501
         :rtype: DrawingObjectCollection
@@ -98,12 +99,14 @@ class DrawingObjectsResponse(object):
     def drawing_objects(self, drawing_objects):
         """Sets the drawing_objects of this DrawingObjectsResponse.
 
-        Gets or sets drawing_objects.  # noqa: E501
+        Gets or sets collection of drawing objects.  # noqa: E501
 
         :param drawing_objects: The drawing_objects of this DrawingObjectsResponse.  # noqa: E501
         :type: DrawingObjectCollection
         """
         self._drawing_objects = drawing_objects
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class DrawingObjectsResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
