@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Field.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="field.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,42 +41,86 @@ class Field(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'field_code': 'str',
         'link': 'WordsApiLink',
         'node_id': 'str',
+        'field_code': 'str',
         'locale_id': 'str',
         'result': 'str'
     }
 
     attribute_map = {
-        'field_code': 'FieldCode',
-        'link': 'link',
+        'link': 'Link',
         'node_id': 'NodeId',
+        'field_code': 'FieldCode',
         'locale_id': 'LocaleId',
         'result': 'Result'
     }
 
-    def __init__(self, field_code=None, link=None, node_id=None, locale_id=None, result=None):  # noqa: E501
+    def __init__(self, link=None, node_id=None, field_code=None, locale_id=None, result=None):  # noqa: E501
         """Field - a model defined in Swagger"""  # noqa: E501
 
-        self._field_code = None
         self._link = None
         self._node_id = None
+        self._field_code = None
         self._locale_id = None
         self._result = None
         self.discriminator = None
 
-        if field_code is not None:
-            self.field_code = field_code
         if link is not None:
             self.link = link
         if node_id is not None:
             self.node_id = node_id
+        if field_code is not None:
+            self.field_code = field_code
         if locale_id is not None:
             self.locale_id = locale_id
         if result is not None:
             self.result = result
 
+    @property
+    def link(self):
+        """Gets the link of this Field.  # noqa: E501
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :return: The link of this Field.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this Field.
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :param link: The link of this Field.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
+
+    @property
+    def node_id(self):
+        """Gets the node_id of this Field.  # noqa: E501
+
+        Gets or sets node id.  # noqa: E501
+
+        :return: The node_id of this Field.  # noqa: E501
+        :rtype: str
+        """
+        return self._node_id
+
+    @node_id.setter
+    def node_id(self, node_id):
+        """Sets the node_id of this Field.
+
+        Gets or sets node id.  # noqa: E501
+
+        :param node_id: The node_id of this Field.  # noqa: E501
+        :type: str
+        """
+        self._node_id = node_id
+
     @property
     def field_code(self):
         """Gets the field_code of this Field.  # noqa: E501
@@ -98,48 +142,7 @@ class Field(object):
         :type: str
         """
         self._field_code = field_code
-    @property
-    def link(self):
-        """Gets the link of this Field.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
-
-        :return: The link of this Field.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this Field.
-
-        Gets or sets link.  # noqa: E501
-
-        :param link: The link of this Field.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
-    @property
-    def node_id(self):
-        """Gets the node_id of this Field.  # noqa: E501
-
-        Gets or sets node id.  # noqa: E501
-
-        :return: The node_id of this Field.  # noqa: E501
-        :rtype: str
-        """
-        return self._node_id
-
-    @node_id.setter
-    def node_id(self, node_id):
-        """Sets the node_id of this Field.
-
-        Gets or sets node id.  # noqa: E501
-
-        :param node_id: The node_id of this Field.  # noqa: E501
-        :type: str
-        """
-        self._node_id = node_id
     @property
     def locale_id(self):
         """Gets the locale_id of this Field.  # noqa: E501
@@ -161,6 +164,7 @@ class Field(object):
         :type: str
         """
         self._locale_id = locale_id
+
     @property
     def result(self):
         """Gets the result of this Field.  # noqa: E501
@@ -182,6 +186,8 @@ class Field(object):
         :type: str
         """
         self._result = result
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -223,4 +229,4 @@ class Field(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
