@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="FieldLink.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="field_link.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,32 +41,54 @@ class FieldLink(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'node_id': 'str',
         'link': 'WordsApiLink',
+        'node_id': 'str',
         'field_code': 'str'
     }
 
     attribute_map = {
+        'link': 'Link',
         'node_id': 'NodeId',
-        'link': 'link',
         'field_code': 'FieldCode'
     }
 
-    def __init__(self, node_id=None, link=None, field_code=None):  # noqa: E501
+    def __init__(self, link=None, node_id=None, field_code=None):  # noqa: E501
         """FieldLink - a model defined in Swagger"""  # noqa: E501
 
-        self._node_id = None
         self._link = None
+        self._node_id = None
         self._field_code = None
         self.discriminator = None
 
-        if node_id is not None:
-            self.node_id = node_id
         if link is not None:
             self.link = link
+        if node_id is not None:
+            self.node_id = node_id
         if field_code is not None:
             self.field_code = field_code
 
+    @property
+    def link(self):
+        """Gets the link of this FieldLink.  # noqa: E501
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :return: The link of this FieldLink.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this FieldLink.
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :param link: The link of this FieldLink.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
+
     @property
     def node_id(self):
         """Gets the node_id of this FieldLink.  # noqa: E501
@@ -88,27 +110,7 @@ class FieldLink(object):
         :type: str
         """
         self._node_id = node_id
-    @property
-    def link(self):
-        """Gets the link of this FieldLink.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
-
-        :return: The link of this FieldLink.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this FieldLink.
-
-        Gets or sets link.  # noqa: E501
-
-        :param link: The link of this FieldLink.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
     @property
     def field_code(self):
         """Gets the field_code of this FieldLink.  # noqa: E501
@@ -130,6 +132,8 @@ class FieldLink(object):
         :type: str
         """
         self._field_code = field_code
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -171,4 +175,4 @@ class FieldLink(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
