@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="FormFieldCheckbox.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="form_field_checkbox.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,6 +41,8 @@ class FormFieldCheckbox(object):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'link': 'WordsApiLink',
+        'node_id': 'str',
         'calculate_on_exit': 'bool',
         'enabled': 'bool',
         'entry_macro': 'str',
@@ -50,14 +52,14 @@ class FormFieldCheckbox(object):
         'own_help': 'bool',
         'own_status': 'bool',
         'status_text': 'str',
-        'link': 'WordsApiLink',
-        'node_id': 'str',
         'check_box_size': 'float',
         'checked': 'bool',
         'is_check_box_exact_size': 'bool'
     }
 
     attribute_map = {
+        'link': 'Link',
+        'node_id': 'NodeId',
         'calculate_on_exit': 'CalculateOnExit',
         'enabled': 'Enabled',
         'entry_macro': 'EntryMacro',
@@ -67,16 +69,16 @@ class FormFieldCheckbox(object):
         'own_help': 'OwnHelp',
         'own_status': 'OwnStatus',
         'status_text': 'StatusText',
-        'link': 'link',
-        'node_id': 'NodeId',
         'check_box_size': 'CheckBoxSize',
         'checked': 'Checked',
         'is_check_box_exact_size': 'IsCheckBoxExactSize'
     }
 
-    def __init__(self, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, link=None, node_id=None, check_box_size=None, checked=None, is_check_box_exact_size=None):  # noqa: E501
+    def __init__(self, link=None, node_id=None, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, check_box_size=None, checked=None, is_check_box_exact_size=None):  # noqa: E501
         """FormFieldCheckbox - a model defined in Swagger"""  # noqa: E501
 
+        self._link = None
+        self._node_id = None
         self._calculate_on_exit = None
         self._enabled = None
         self._entry_macro = None
@@ -86,13 +88,15 @@ class FormFieldCheckbox(object):
         self._own_help = None
         self._own_status = None
         self._status_text = None
-        self._link = None
-        self._node_id = None
         self._check_box_size = None
         self._checked = None
         self._is_check_box_exact_size = None
         self.discriminator = None
 
+        if link is not None:
+            self.link = link
+        if node_id is not None:
+            self.node_id = node_id
         if calculate_on_exit is not None:
             self.calculate_on_exit = calculate_on_exit
         if enabled is not None:
@@ -111,10 +115,6 @@ class FormFieldCheckbox(object):
             self.own_status = own_status
         if status_text is not None:
             self.status_text = status_text
-        if link is not None:
-            self.link = link
-        if node_id is not None:
-            self.node_id = node_id
         if check_box_size is not None:
             self.check_box_size = check_box_size
         if checked is not None:
@@ -122,6 +122,50 @@ class FormFieldCheckbox(object):
         if is_check_box_exact_size is not None:
             self.is_check_box_exact_size = is_check_box_exact_size
 
+    @property
+    def link(self):
+        """Gets the link of this FormFieldCheckbox.  # noqa: E501
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :return: The link of this FormFieldCheckbox.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this FormFieldCheckbox.
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :param link: The link of this FormFieldCheckbox.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
+
+    @property
+    def node_id(self):
+        """Gets the node_id of this FormFieldCheckbox.  # noqa: E501
+
+        Gets or sets node id.  # noqa: E501
+
+        :return: The node_id of this FormFieldCheckbox.  # noqa: E501
+        :rtype: str
+        """
+        return self._node_id
+
+    @node_id.setter
+    def node_id(self, node_id):
+        """Sets the node_id of this FormFieldCheckbox.
+
+        Gets or sets node id.  # noqa: E501
+
+        :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
+        :type: str
+        """
+        self._node_id = node_id
+
     @property
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
@@ -143,6 +187,7 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._calculate_on_exit = calculate_on_exit
+
     @property
     def enabled(self):
         """Gets the enabled of this FormFieldCheckbox.  # noqa: E501
@@ -164,6 +209,7 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._enabled = enabled
+
     @property
     def entry_macro(self):
         """Gets the entry_macro of this FormFieldCheckbox.  # noqa: E501
@@ -185,6 +231,7 @@ class FormFieldCheckbox(object):
         :type: str
         """
         self._entry_macro = entry_macro
+
     @property
     def exit_macro(self):
         """Gets the exit_macro of this FormFieldCheckbox.  # noqa: E501
@@ -206,6 +253,7 @@ class FormFieldCheckbox(object):
         :type: str
         """
         self._exit_macro = exit_macro
+
     @property
     def help_text(self):
         """Gets the help_text of this FormFieldCheckbox.  # noqa: E501
@@ -227,6 +275,7 @@ class FormFieldCheckbox(object):
         :type: str
         """
         self._help_text = help_text
+
     @property
     def name(self):
         """Gets the name of this FormFieldCheckbox.  # noqa: E501
@@ -248,6 +297,7 @@ class FormFieldCheckbox(object):
         :type: str
         """
         self._name = name
+
     @property
     def own_help(self):
         """Gets the own_help of this FormFieldCheckbox.  # noqa: E501
@@ -269,6 +319,7 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._own_help = own_help
+
     @property
     def own_status(self):
         """Gets the own_status of this FormFieldCheckbox.  # noqa: E501
@@ -290,6 +341,7 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._own_status = own_status
+
     @property
     def status_text(self):
         """Gets the status_text of this FormFieldCheckbox.  # noqa: E501
@@ -311,48 +363,7 @@ class FormFieldCheckbox(object):
         :type: str
         """
         self._status_text = status_text
-    @property
-    def link(self):
-        """Gets the link of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
-
-        :return: The link of this FormFieldCheckbox.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this FormFieldCheckbox.
-
-        Gets or sets link.  # noqa: E501
-
-        :param link: The link of this FormFieldCheckbox.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
-    @property
-    def node_id(self):
-        """Gets the node_id of this FormFieldCheckbox.  # noqa: E501
-
-        Gets or sets node id.  # noqa: E501
-
-        :return: The node_id of this FormFieldCheckbox.  # noqa: E501
-        :rtype: str
-        """
-        return self._node_id
-
-    @node_id.setter
-    def node_id(self, node_id):
-        """Sets the node_id of this FormFieldCheckbox.
-
-        Gets or sets node id.  # noqa: E501
-
-        :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
-        :type: str
-        """
-        self._node_id = node_id
     @property
     def check_box_size(self):
         """Gets the check_box_size of this FormFieldCheckbox.  # noqa: E501
@@ -374,6 +385,7 @@ class FormFieldCheckbox(object):
         :type: float
         """
         self._check_box_size = check_box_size
+
     @property
     def checked(self):
         """Gets the checked of this FormFieldCheckbox.  # noqa: E501
@@ -395,6 +407,7 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._checked = checked
+
     @property
     def is_check_box_exact_size(self):
         """Gets the is_check_box_exact_size of this FormFieldCheckbox.  # noqa: E501
@@ -416,6 +429,8 @@ class FormFieldCheckbox(object):
         :type: bool
         """
         self._is_check_box_exact_size = is_check_box_exact_size
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -457,4 +472,4 @@ class FormFieldCheckbox(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
