@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Link.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="link.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -43,40 +43,40 @@ class Link(object):
     swagger_types = {
         'href': 'str',
         'rel': 'str',
-        'type': 'str',
-        'title': 'str'
+        'title': 'str',
+        'type': 'str'
     }
 
     attribute_map = {
         'href': 'Href',
         'rel': 'Rel',
-        'type': 'Type',
-        'title': 'Title'
+        'title': 'Title',
+        'type': 'Type'
     }
 
-    def __init__(self, href=None, rel=None, type=None, title=None):  # noqa: E501
+    def __init__(self, href=None, rel=None, title=None, type=None):  # noqa: E501
         """Link - a model defined in Swagger"""  # noqa: E501
 
         self._href = None
         self._rel = None
-        self._type = None
         self._title = None
+        self._type = None
         self.discriminator = None
 
         if href is not None:
             self.href = href
         if rel is not None:
             self.rel = rel
-        if type is not None:
-            self.type = type
         if title is not None:
             self.title = title
+        if type is not None:
+            self.type = type
 
     @property
     def href(self):
         """Gets the href of this Link.  # noqa: E501
 
-        Gets or sets the \"href\" attribute contains the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501
+        Gets or sets the "href" attribute contains the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501
 
         :return: The href of this Link.  # noqa: E501
         :rtype: str
@@ -87,17 +87,18 @@ class Link(object):
     def href(self, href):
         """Sets the href of this Link.
 
-        Gets or sets the \"href\" attribute contains the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501
+        Gets or sets the "href" attribute contains the link's IRI. atom:link elements MUST have an href attribute, whose value MUST be a IRI reference.  # noqa: E501
 
         :param href: The href of this Link.  # noqa: E501
         :type: str
         """
         self._href = href
+
     @property
     def rel(self):
         """Gets the rel of this Link.  # noqa: E501
 
-        Gets or sets atom:link elements MAY have a \"rel\" attribute that indicates the link relation type.  If the \"rel\" attribute is not present, the link element MUST be interpreted as if the link relation type is \"alternate\".  # noqa: E501
+        Gets or sets atom:link elements MAY have a "rel" attribute that indicates the link relation type.  If the "rel" attribute is not present, the link element MUST be interpreted as if the link relation type is "alternate".  # noqa: E501
 
         :return: The rel of this Link.  # noqa: E501
         :rtype: str
@@ -108,38 +109,18 @@ class Link(object):
     def rel(self, rel):
         """Sets the rel of this Link.
 
-        Gets or sets atom:link elements MAY have a \"rel\" attribute that indicates the link relation type.  If the \"rel\" attribute is not present, the link element MUST be interpreted as if the link relation type is \"alternate\".  # noqa: E501
+        Gets or sets atom:link elements MAY have a "rel" attribute that indicates the link relation type.  If the "rel" attribute is not present, the link element MUST be interpreted as if the link relation type is "alternate".  # noqa: E501
 
         :param rel: The rel of this Link.  # noqa: E501
         :type: str
         """
         self._rel = rel
-    @property
-    def type(self):
-        """Gets the type of this Link.  # noqa: E501
 
-        Gets or sets on the link element, the \"type\" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced.  Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501
-
-        :return: The type of this Link.  # noqa: E501
-        :rtype: str
-        """
-        return self._type
-
-    @type.setter
-    def type(self, type):
-        """Sets the type of this Link.
-
-        Gets or sets on the link element, the \"type\" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced.  Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501
-
-        :param type: The type of this Link.  # noqa: E501
-        :type: str
-        """
-        self._type = type
     @property
     def title(self):
         """Gets the title of this Link.  # noqa: E501
 
-        Gets or sets the \"title\" attribute conveys human-readable information about the link.  The content of the \"title\" attribute is Language-Sensitive.  # noqa: E501
+        Gets or sets the "title" attribute conveys human-readable information about the link.  The content of the "title" attribute is Language-Sensitive.  # noqa: E501
 
         :return: The title of this Link.  # noqa: E501
         :rtype: str
@@ -150,12 +131,36 @@ class Link(object):
     def title(self, title):
         """Sets the title of this Link.
 
-        Gets or sets the \"title\" attribute conveys human-readable information about the link.  The content of the \"title\" attribute is Language-Sensitive.  # noqa: E501
+        Gets or sets the "title" attribute conveys human-readable information about the link.  The content of the "title" attribute is Language-Sensitive.  # noqa: E501
 
         :param title: The title of this Link.  # noqa: E501
         :type: str
         """
         self._title = title
+
+    @property
+    def type(self):
+        """Gets the type of this Link.  # noqa: E501
+
+        Gets or sets on the link element, the "type" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced.  Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501
+
+        :return: The type of this Link.  # noqa: E501
+        :rtype: str
+        """
+        return self._type
+
+    @type.setter
+    def type(self, type):
+        """Sets the type of this Link.
+
+        Gets or sets on the link element, the "type" attribute's value is an advisory media type: it is a hint about the type of the representation that is expected to be returned when the value of the href attribute is dereferenced.  Note that the type attribute does not override the actual media type returned with the representation.  # noqa: E501
+
+        :param type: The type of this Link.  # noqa: E501
+        :type: str
+        """
+        self._type = type
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -197,4 +202,4 @@ class Link(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
