@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="ListLevelUpdate.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="list_level_update.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,66 +41,214 @@ class ListLevelUpdate(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'start_at': 'int',
-        'number_style': 'str',
-        'number_format': 'str',
         'alignment': 'str',
         'is_legal': 'bool',
-        'restart_after_level': 'int',
-        'trailing_character': 'str',
-        'tab_position': 'float',
+        'number_format': 'str',
         'number_position': 'float',
-        'text_position': 'float'
+        'number_style': 'str',
+        'restart_after_level': 'int',
+        'start_at': 'int',
+        'tab_position': 'float',
+        'text_position': 'float',
+        'trailing_character': 'str'
     }
 
     attribute_map = {
-        'start_at': 'StartAt',
-        'number_style': 'NumberStyle',
-        'number_format': 'NumberFormat',
         'alignment': 'Alignment',
         'is_legal': 'IsLegal',
-        'restart_after_level': 'RestartAfterLevel',
-        'trailing_character': 'TrailingCharacter',
-        'tab_position': 'TabPosition',
+        'number_format': 'NumberFormat',
         'number_position': 'NumberPosition',
-        'text_position': 'TextPosition'
+        'number_style': 'NumberStyle',
+        'restart_after_level': 'RestartAfterLevel',
+        'start_at': 'StartAt',
+        'tab_position': 'TabPosition',
+        'text_position': 'TextPosition',
+        'trailing_character': 'TrailingCharacter'
     }
 
-    def __init__(self, start_at=None, number_style=None, number_format=None, alignment=None, is_legal=None, restart_after_level=None, trailing_character=None, tab_position=None, number_position=None, text_position=None):  # noqa: E501
+    def __init__(self, alignment=None, is_legal=None, number_format=None, number_position=None, number_style=None, restart_after_level=None, start_at=None, tab_position=None, text_position=None, trailing_character=None):  # noqa: E501
         """ListLevelUpdate - a model defined in Swagger"""  # noqa: E501
 
-        self._start_at = None
-        self._number_style = None
-        self._number_format = None
         self._alignment = None
         self._is_legal = None
-        self._restart_after_level = None
-        self._trailing_character = None
-        self._tab_position = None
+        self._number_format = None
         self._number_position = None
+        self._number_style = None
+        self._restart_after_level = None
+        self._start_at = None
+        self._tab_position = None
         self._text_position = None
+        self._trailing_character = None
         self.discriminator = None
 
-        if start_at is not None:
-            self.start_at = start_at
-        if number_style is not None:
-            self.number_style = number_style
-        if number_format is not None:
-            self.number_format = number_format
         if alignment is not None:
             self.alignment = alignment
         if is_legal is not None:
             self.is_legal = is_legal
-        if restart_after_level is not None:
-            self.restart_after_level = restart_after_level
-        if trailing_character is not None:
-            self.trailing_character = trailing_character
-        if tab_position is not None:
-            self.tab_position = tab_position
+        if number_format is not None:
+            self.number_format = number_format
         if number_position is not None:
             self.number_position = number_position
+        if number_style is not None:
+            self.number_style = number_style
+        if restart_after_level is not None:
+            self.restart_after_level = restart_after_level
+        if start_at is not None:
+            self.start_at = start_at
+        if tab_position is not None:
+            self.tab_position = tab_position
         if text_position is not None:
             self.text_position = text_position
+        if trailing_character is not None:
+            self.trailing_character = trailing_character
+
+    @property
+    def alignment(self):
+        """Gets the alignment of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets the justification of the actual number of the list item.  # noqa: E501
+
+        :return: The alignment of this ListLevelUpdate.  # noqa: E501
+        :rtype: str
+        """
+        return self._alignment
+
+    @alignment.setter
+    def alignment(self, alignment):
+        """Sets the alignment of this ListLevelUpdate.
+
+        Gets or sets the justification of the actual number of the list item.  # noqa: E501
+
+        :param alignment: The alignment of this ListLevelUpdate.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Left", "Center", "Right"]  # noqa: E501
+        if not alignment.isdigit():
+            if alignment not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
+                    .format(alignment, allowed_values))
+            self._alignment = alignment
+        else:
+            self._alignment = allowed_values[int(alignment) if six.PY3 else long(alignment)]
+
+    @property
+    def is_legal(self):
+        """Gets the is_legal of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets a value indicating whether true if the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501
+
+        :return: The is_legal of this ListLevelUpdate.  # noqa: E501
+        :rtype: bool
+        """
+        return self._is_legal
+
+    @is_legal.setter
+    def is_legal(self, is_legal):
+        """Sets the is_legal of this ListLevelUpdate.
+
+        Gets or sets a value indicating whether true if the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501
+
+        :param is_legal: The is_legal of this ListLevelUpdate.  # noqa: E501
+        :type: bool
+        """
+        self._is_legal = is_legal
+
+    @property
+    def number_format(self):
+        """Gets the number_format of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets returns or sets the number format for the list level.  # noqa: E501
+
+        :return: The number_format of this ListLevelUpdate.  # noqa: E501
+        :rtype: str
+        """
+        return self._number_format
+
+    @number_format.setter
+    def number_format(self, number_format):
+        """Sets the number_format of this ListLevelUpdate.
+
+        Gets or sets returns or sets the number format for the list level.  # noqa: E501
+
+        :param number_format: The number_format of this ListLevelUpdate.  # noqa: E501
+        :type: str
+        """
+        self._number_format = number_format
+
+    @property
+    def number_position(self):
+        """Gets the number_position of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets returns or sets the position (in points) of the number or bullet for the list level.  # noqa: E501
+
+        :return: The number_position of this ListLevelUpdate.  # noqa: E501
+        :rtype: float
+        """
+        return self._number_position
+
+    @number_position.setter
+    def number_position(self, number_position):
+        """Sets the number_position of this ListLevelUpdate.
+
+        Gets or sets returns or sets the position (in points) of the number or bullet for the list level.  # noqa: E501
+
+        :param number_position: The number_position of this ListLevelUpdate.  # noqa: E501
+        :type: float
+        """
+        self._number_position = number_position
+
+    @property
+    def number_style(self):
+        """Gets the number_style of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets returns or sets the number style for this list level.  # noqa: E501
+
+        :return: The number_style of this ListLevelUpdate.  # noqa: E501
+        :rtype: str
+        """
+        return self._number_style
+
+    @number_style.setter
+    def number_style(self, number_style):
+        """Sets the number_style of this ListLevelUpdate.
+
+        Gets or sets returns or sets the number style for this list level.  # noqa: E501
+
+        :param number_style: The number_style of this ListLevelUpdate.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
+        if not number_style.isdigit():
+            if number_style not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `number_style` ({0}), must be one of {1}"  # noqa: E501
+                    .format(number_style, allowed_values))
+            self._number_style = number_style
+        else:
+            self._number_style = allowed_values[int(number_style) if six.PY3 else long(number_style)]
+
+    @property
+    def restart_after_level(self):
+        """Gets the restart_after_level of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets or returns the list level that must appear before the specified list level restarts numbering.  # noqa: E501
+
+        :return: The restart_after_level of this ListLevelUpdate.  # noqa: E501
+        :rtype: int
+        """
+        return self._restart_after_level
+
+    @restart_after_level.setter
+    def restart_after_level(self, restart_after_level):
+        """Sets the restart_after_level of this ListLevelUpdate.
+
+        Gets or sets or returns the list level that must appear before the specified list level restarts numbering.  # noqa: E501
+
+        :param restart_after_level: The restart_after_level of this ListLevelUpdate.  # noqa: E501
+        :type: int
+        """
+        self._restart_after_level = restart_after_level
 
     @property
     def start_at(self):
@@ -123,156 +271,7 @@ class ListLevelUpdate(object):
         :type: int
         """
         self._start_at = start_at
-    @property
-    def number_style(self):
-        """Gets the number_style of this ListLevelUpdate.  # noqa: E501
 
-        Gets or sets returns or sets the number style for this list level.  # noqa: E501
-
-        :return: The number_style of this ListLevelUpdate.  # noqa: E501
-        :rtype: str
-        """
-        return self._number_style
-
-    @number_style.setter
-    def number_style(self, number_style):
-        """Sets the number_style of this ListLevelUpdate.
-
-        Gets or sets returns or sets the number style for this list level.  # noqa: E501
-
-        :param number_style: The number_style of this ListLevelUpdate.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
-        if not number_style.isdigit():	
-            if number_style not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `number_style` ({0}), must be one of {1}"  # noqa: E501
-                    .format(number_style, allowed_values))
-            self._number_style = number_style
-        else:
-            self._number_style = allowed_values[int(number_style) if six.PY3 else long(number_style)]
-    @property
-    def number_format(self):
-        """Gets the number_format of this ListLevelUpdate.  # noqa: E501
-
-        Gets or sets returns or sets the number format for the list level.  # noqa: E501
-
-        :return: The number_format of this ListLevelUpdate.  # noqa: E501
-        :rtype: str
-        """
-        return self._number_format
-
-    @number_format.setter
-    def number_format(self, number_format):
-        """Sets the number_format of this ListLevelUpdate.
-
-        Gets or sets returns or sets the number format for the list level.  # noqa: E501
-
-        :param number_format: The number_format of this ListLevelUpdate.  # noqa: E501
-        :type: str
-        """
-        self._number_format = number_format
-    @property
-    def alignment(self):
-        """Gets the alignment of this ListLevelUpdate.  # noqa: E501
-
-        Gets or sets the justification of the actual number of the list item.  # noqa: E501
-
-        :return: The alignment of this ListLevelUpdate.  # noqa: E501
-        :rtype: str
-        """
-        return self._alignment
-
-    @alignment.setter
-    def alignment(self, alignment):
-        """Sets the alignment of this ListLevelUpdate.
-
-        Gets or sets the justification of the actual number of the list item.  # noqa: E501
-
-        :param alignment: The alignment of this ListLevelUpdate.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Left", "Center", "Right"]  # noqa: E501
-        if not alignment.isdigit():	
-            if alignment not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `alignment` ({0}), must be one of {1}"  # noqa: E501
-                    .format(alignment, allowed_values))
-            self._alignment = alignment
-        else:
-            self._alignment = allowed_values[int(alignment) if six.PY3 else long(alignment)]
-    @property
-    def is_legal(self):
-        """Gets the is_legal of this ListLevelUpdate.  # noqa: E501
-
-        Gets or sets a value indicating whether true if the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501
-
-        :return: The is_legal of this ListLevelUpdate.  # noqa: E501
-        :rtype: bool
-        """
-        return self._is_legal
-
-    @is_legal.setter
-    def is_legal(self, is_legal):
-        """Sets the is_legal of this ListLevelUpdate.
-
-        Gets or sets a value indicating whether true if the level turns all inherited numbers to Arabic, false if it preserves their number style.  # noqa: E501
-
-        :param is_legal: The is_legal of this ListLevelUpdate.  # noqa: E501
-        :type: bool
-        """
-        self._is_legal = is_legal
-    @property
-    def restart_after_level(self):
-        """Gets the restart_after_level of this ListLevelUpdate.  # noqa: E501
-
-        Gets or sets or returns the list level that must appear before the specified list level restarts numbering.  # noqa: E501
-
-        :return: The restart_after_level of this ListLevelUpdate.  # noqa: E501
-        :rtype: int
-        """
-        return self._restart_after_level
-
-    @restart_after_level.setter
-    def restart_after_level(self, restart_after_level):
-        """Sets the restart_after_level of this ListLevelUpdate.
-
-        Gets or sets or returns the list level that must appear before the specified list level restarts numbering.  # noqa: E501
-
-        :param restart_after_level: The restart_after_level of this ListLevelUpdate.  # noqa: E501
-        :type: int
-        """
-        self._restart_after_level = restart_after_level
-    @property
-    def trailing_character(self):
-        """Gets the trailing_character of this ListLevelUpdate.  # noqa: E501
-
-        Gets or sets returns or sets the character inserted after the number for the list level.  # noqa: E501
-
-        :return: The trailing_character of this ListLevelUpdate.  # noqa: E501
-        :rtype: str
-        """
-        return self._trailing_character
-
-    @trailing_character.setter
-    def trailing_character(self, trailing_character):
-        """Sets the trailing_character of this ListLevelUpdate.
-
-        Gets or sets returns or sets the character inserted after the number for the list level.  # noqa: E501
-
-        :param trailing_character: The trailing_character of this ListLevelUpdate.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Tab", "Space", "Nothing"]  # noqa: E501
-        if not trailing_character.isdigit():	
-            if trailing_character not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `trailing_character` ({0}), must be one of {1}"  # noqa: E501
-                    .format(trailing_character, allowed_values))
-            self._trailing_character = trailing_character
-        else:
-            self._trailing_character = allowed_values[int(trailing_character) if six.PY3 else long(trailing_character)]
     @property
     def tab_position(self):
         """Gets the tab_position of this ListLevelUpdate.  # noqa: E501
@@ -294,27 +293,7 @@ class ListLevelUpdate(object):
         :type: float
         """
         self._tab_position = tab_position
-    @property
-    def number_position(self):
-        """Gets the number_position of this ListLevelUpdate.  # noqa: E501
 
-        Gets or sets returns or sets the position (in points) of the number or bullet for the list level.  # noqa: E501
-
-        :return: The number_position of this ListLevelUpdate.  # noqa: E501
-        :rtype: float
-        """
-        return self._number_position
-
-    @number_position.setter
-    def number_position(self, number_position):
-        """Sets the number_position of this ListLevelUpdate.
-
-        Gets or sets returns or sets the position (in points) of the number or bullet for the list level.  # noqa: E501
-
-        :param number_position: The number_position of this ListLevelUpdate.  # noqa: E501
-        :type: float
-        """
-        self._number_position = number_position
     @property
     def text_position(self):
         """Gets the text_position of this ListLevelUpdate.  # noqa: E501
@@ -336,6 +315,38 @@ class ListLevelUpdate(object):
         :type: float
         """
         self._text_position = text_position
+
+    @property
+    def trailing_character(self):
+        """Gets the trailing_character of this ListLevelUpdate.  # noqa: E501
+
+        Gets or sets returns or sets the character inserted after the number for the list level.  # noqa: E501
+
+        :return: The trailing_character of this ListLevelUpdate.  # noqa: E501
+        :rtype: str
+        """
+        return self._trailing_character
+
+    @trailing_character.setter
+    def trailing_character(self, trailing_character):
+        """Sets the trailing_character of this ListLevelUpdate.
+
+        Gets or sets returns or sets the character inserted after the number for the list level.  # noqa: E501
+
+        :param trailing_character: The trailing_character of this ListLevelUpdate.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Tab", "Space", "Nothing"]  # noqa: E501
+        if not trailing_character.isdigit():
+            if trailing_character not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `trailing_character` ({0}), must be one of {1}"  # noqa: E501
+                    .format(trailing_character, allowed_values))
+            self._trailing_character = trailing_character
+        else:
+            self._trailing_character = allowed_values[int(trailing_character) if six.PY3 else long(trailing_character)]
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -377,4 +388,4 @@ class ListLevelUpdate(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
