@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="MetafileRenderingOptionsData.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="metafile_rendering_options_data.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -44,26 +44,26 @@ class MetafileRenderingOptionsData(object):
         'emf_plus_dual_rendering_mode': 'str',
         'emulate_raster_operations': 'bool',
         'rendering_mode': 'str',
-        'use_emf_embedded_to_wmf': 'bool',
-        'scale_wmf_fonts_to_metafile_size': 'bool'
+        'scale_wmf_fonts_to_metafile_size': 'bool',
+        'use_emf_embedded_to_wmf': 'bool'
     }
 
     attribute_map = {
         'emf_plus_dual_rendering_mode': 'EmfPlusDualRenderingMode',
         'emulate_raster_operations': 'EmulateRasterOperations',
         'rendering_mode': 'RenderingMode',
-        'use_emf_embedded_to_wmf': 'UseEmfEmbeddedToWmf',
-        'scale_wmf_fonts_to_metafile_size': 'ScaleWmfFontsToMetafileSize'
+        'scale_wmf_fonts_to_metafile_size': 'ScaleWmfFontsToMetafileSize',
+        'use_emf_embedded_to_wmf': 'UseEmfEmbeddedToWmf'
     }
 
-    def __init__(self, emf_plus_dual_rendering_mode=None, emulate_raster_operations=None, rendering_mode=None, use_emf_embedded_to_wmf=None, scale_wmf_fonts_to_metafile_size=None):  # noqa: E501
+    def __init__(self, emf_plus_dual_rendering_mode=None, emulate_raster_operations=None, rendering_mode=None, scale_wmf_fonts_to_metafile_size=None, use_emf_embedded_to_wmf=None):  # noqa: E501
         """MetafileRenderingOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._emf_plus_dual_rendering_mode = None
         self._emulate_raster_operations = None
         self._rendering_mode = None
-        self._use_emf_embedded_to_wmf = None
         self._scale_wmf_fonts_to_metafile_size = None
+        self._use_emf_embedded_to_wmf = None
         self.discriminator = None
 
         if emf_plus_dual_rendering_mode is not None:
@@ -72,10 +72,10 @@ class MetafileRenderingOptionsData(object):
             self.emulate_raster_operations = emulate_raster_operations
         if rendering_mode is not None:
             self.rendering_mode = rendering_mode
-        if use_emf_embedded_to_wmf is not None:
-            self.use_emf_embedded_to_wmf = use_emf_embedded_to_wmf
         if scale_wmf_fonts_to_metafile_size is not None:
             self.scale_wmf_fonts_to_metafile_size = scale_wmf_fonts_to_metafile_size
+        if use_emf_embedded_to_wmf is not None:
+            self.use_emf_embedded_to_wmf = use_emf_embedded_to_wmf
 
     @property
     def emf_plus_dual_rendering_mode(self):
@@ -98,11 +98,12 @@ class MetafileRenderingOptionsData(object):
         :type: str
         """
         self._emf_plus_dual_rendering_mode = emf_plus_dual_rendering_mode
+
     @property
     def emulate_raster_operations(self):
         """Gets the emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501
 
-        Gets or sets a value determining whether or not the raster operations should be emulated.               # noqa: E501
+        Gets or sets a value determining whether or not the raster operations should be emulated.  # noqa: E501
 
         :return: The emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501
         :rtype: bool
@@ -113,12 +114,13 @@ class MetafileRenderingOptionsData(object):
     def emulate_raster_operations(self, emulate_raster_operations):
         """Sets the emulate_raster_operations of this MetafileRenderingOptionsData.
 
-        Gets or sets a value determining whether or not the raster operations should be emulated.               # noqa: E501
+        Gets or sets a value determining whether or not the raster operations should be emulated.  # noqa: E501
 
         :param emulate_raster_operations: The emulate_raster_operations of this MetafileRenderingOptionsData.  # noqa: E501
         :type: bool
         """
         self._emulate_raster_operations = emulate_raster_operations
+
     @property
     def rendering_mode(self):
         """Gets the rendering_mode of this MetafileRenderingOptionsData.  # noqa: E501
@@ -140,27 +142,7 @@ class MetafileRenderingOptionsData(object):
         :type: str
         """
         self._rendering_mode = rendering_mode
-    @property
-    def use_emf_embedded_to_wmf(self):
-        """Gets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
 
-        Gets or sets determines how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501
-
-        :return: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._use_emf_embedded_to_wmf
-
-    @use_emf_embedded_to_wmf.setter
-    def use_emf_embedded_to_wmf(self, use_emf_embedded_to_wmf):
-        """Sets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.
-
-        Gets or sets determines how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501
-
-        :param use_emf_embedded_to_wmf: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._use_emf_embedded_to_wmf = use_emf_embedded_to_wmf
     @property
     def scale_wmf_fonts_to_metafile_size(self):
         """Gets the scale_wmf_fonts_to_metafile_size of this MetafileRenderingOptionsData.  # noqa: E501
@@ -182,6 +164,30 @@ class MetafileRenderingOptionsData(object):
         :type: bool
         """
         self._scale_wmf_fonts_to_metafile_size = scale_wmf_fonts_to_metafile_size
+
+    @property
+    def use_emf_embedded_to_wmf(self):
+        """Gets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
+
+        Gets or sets determines how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501
+
+        :return: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._use_emf_embedded_to_wmf
+
+    @use_emf_embedded_to_wmf.setter
+    def use_emf_embedded_to_wmf(self, use_emf_embedded_to_wmf):
+        """Sets the use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.
+
+        Gets or sets determines how WMF metafiles with embedded EMF metafiles should be rendered.  # noqa: E501
+
+        :param use_emf_embedded_to_wmf: The use_emf_embedded_to_wmf of this MetafileRenderingOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._use_emf_embedded_to_wmf = use_emf_embedded_to_wmf
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -223,4 +229,4 @@ class MetafileRenderingOptionsData(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
