@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="OoxmlSaveOptionsData.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="ooxml_save_options_data.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,82 +41,183 @@ class OoxmlSaveOptionsData(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'save_format': 'str',
-        'file_name': 'str',
-        'dml_rendering_mode': 'str',
+        'dml3_d_effects_rendering_mode': 'str',
         'dml_effects_rendering_mode': 'str',
-        'zip_output': 'bool',
+        'dml_rendering_mode': 'str',
+        'file_name': 'str',
+        'save_format': 'str',
+        'update_fields': 'bool',
+        'update_last_printed_property': 'bool',
         'update_last_saved_time_property': 'bool',
         'update_sdt_content': 'bool',
-        'update_fields': 'bool',
-        'dml3_d_effects_rendering_mode': 'str',
-        'update_last_printed_property': 'bool',
+        'zip_output': 'bool',
         'compliance': 'str',
+        'compression_level': 'str',
         'password': 'str',
         'pretty_format': 'bool'
     }
 
     attribute_map = {
-        'save_format': 'SaveFormat',
-        'file_name': 'FileName',
-        'dml_rendering_mode': 'DmlRenderingMode',
+        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
         'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
-        'zip_output': 'ZipOutput',
+        'dml_rendering_mode': 'DmlRenderingMode',
+        'file_name': 'FileName',
+        'save_format': 'SaveFormat',
+        'update_fields': 'UpdateFields',
+        'update_last_printed_property': 'UpdateLastPrintedProperty',
         'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
         'update_sdt_content': 'UpdateSdtContent',
-        'update_fields': 'UpdateFields',
-        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
-        'update_last_printed_property': 'UpdateLastPrintedProperty',
+        'zip_output': 'ZipOutput',
         'compliance': 'Compliance',
+        'compression_level': 'CompressionLevel',
         'password': 'Password',
         'pretty_format': 'PrettyFormat'
     }
 
-    def __init__(self, save_format=None, file_name=None, dml_rendering_mode=None, dml_effects_rendering_mode=None, zip_output=None, update_last_saved_time_property=None, update_sdt_content=None, update_fields=None, dml3_d_effects_rendering_mode=None, update_last_printed_property=None, compliance=None, password=None, pretty_format=None):  # noqa: E501
+    def __init__(self, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, compliance=None, compression_level=None, password=None, pretty_format=None):  # noqa: E501
         """OoxmlSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
-        self._save_format = None
-        self._file_name = None
-        self._dml_rendering_mode = None
+        self._dml3_d_effects_rendering_mode = None
         self._dml_effects_rendering_mode = None
-        self._zip_output = None
+        self._dml_rendering_mode = None
+        self._file_name = None
+        self._save_format = None
+        self._update_fields = None
+        self._update_last_printed_property = None
         self._update_last_saved_time_property = None
         self._update_sdt_content = None
-        self._update_fields = None
-        self._dml3_d_effects_rendering_mode = None
-        self._update_last_printed_property = None
+        self._zip_output = None
         self._compliance = None
+        self._compression_level = None
         self._password = None
         self._pretty_format = None
         self.discriminator = None
 
-        if save_format is not None:
-            self.save_format = save_format
-        if file_name is not None:
-            self.file_name = file_name
-        if dml_rendering_mode is not None:
-            self.dml_rendering_mode = dml_rendering_mode
+        if dml3_d_effects_rendering_mode is not None:
+            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
         if dml_effects_rendering_mode is not None:
             self.dml_effects_rendering_mode = dml_effects_rendering_mode
-        if zip_output is not None:
-            self.zip_output = zip_output
+        if dml_rendering_mode is not None:
+            self.dml_rendering_mode = dml_rendering_mode
+        if file_name is not None:
+            self.file_name = file_name
+        if save_format is not None:
+            self.save_format = save_format
+        if update_fields is not None:
+            self.update_fields = update_fields
+        if update_last_printed_property is not None:
+            self.update_last_printed_property = update_last_printed_property
         if update_last_saved_time_property is not None:
             self.update_last_saved_time_property = update_last_saved_time_property
         if update_sdt_content is not None:
             self.update_sdt_content = update_sdt_content
-        if update_fields is not None:
-            self.update_fields = update_fields
-        if dml3_d_effects_rendering_mode is not None:
-            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        if update_last_printed_property is not None:
-            self.update_last_printed_property = update_last_printed_property
+        if zip_output is not None:
+            self.zip_output = zip_output
         if compliance is not None:
             self.compliance = compliance
+        if compression_level is not None:
+            self.compression_level = compression_level
         if password is not None:
             self.password = password
         if pretty_format is not None:
             self.pretty_format = pretty_format
 
+    @property
+    def dml3_d_effects_rendering_mode(self):
+        """Gets the dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :return: The dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml3_d_effects_rendering_mode
+
+    @dml3_d_effects_rendering_mode.setter
+    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
+        """Sets the dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Basic", "Advanced"]  # noqa: E501
+        if not dml3_d_effects_rendering_mode.isdigit():
+            if dml3_d_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml3_d_effects_rendering_mode, allowed_values))
+            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        else:
+            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
+
+    @property
+    def dml_effects_rendering_mode(self):
+        """Gets the dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :return: The dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_effects_rendering_mode
+
+    @dml_effects_rendering_mode.setter
+    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
+        """Sets the dml_effects_rendering_mode of this OoxmlSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+
+    @property
+    def dml_rendering_mode(self):
+        """Gets the dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :return: The dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_rendering_mode
+
+    @dml_rendering_mode.setter
+    def dml_rendering_mode(self, dml_rendering_mode):
+        """Sets the dml_rendering_mode of this OoxmlSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :param dml_rendering_mode: The dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_rendering_mode = dml_rendering_mode
+
+    @property
+    def file_name(self):
+        """Gets the file_name of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :return: The file_name of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._file_name
+
+    @file_name.setter
+    def file_name(self, file_name):
+        """Sets the file_name of this OoxmlSaveOptionsData.
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :param file_name: The file_name of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._file_name = file_name
+
     @property
     def save_format(self):
         """Gets the save_format of this OoxmlSaveOptionsData.  # noqa: E501
@@ -138,137 +239,12 @@ class OoxmlSaveOptionsData(object):
         :type: str
         """
         self._save_format = save_format
-    @property
-    def file_name(self):
-        """Gets the file_name of this OoxmlSaveOptionsData.  # noqa: E501
 
-        Gets or sets name of destination file.  # noqa: E501
-
-        :return: The file_name of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._file_name
-
-    @file_name.setter
-    def file_name(self, file_name):
-        """Sets the file_name of this OoxmlSaveOptionsData.
-
-        Gets or sets name of destination file.  # noqa: E501
-
-        :param file_name: The file_name of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._file_name = file_name
-    @property
-    def dml_rendering_mode(self):
-        """Gets the dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :return: The dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_rendering_mode
-
-    @dml_rendering_mode.setter
-    def dml_rendering_mode(self, dml_rendering_mode):
-        """Sets the dml_rendering_mode of this OoxmlSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :param dml_rendering_mode: The dml_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_rendering_mode = dml_rendering_mode
-    @property
-    def dml_effects_rendering_mode(self):
-        """Gets the dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :return: The dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_effects_rendering_mode
-
-    @dml_effects_rendering_mode.setter
-    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
-        """Sets the dml_effects_rendering_mode of this OoxmlSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
-    @property
-    def zip_output(self):
-        """Gets the zip_output of this OoxmlSaveOptionsData.  # noqa: E501
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :return: The zip_output of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._zip_output
-
-    @zip_output.setter
-    def zip_output(self, zip_output):
-        """Sets the zip_output of this OoxmlSaveOptionsData.
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :param zip_output: The zip_output of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._zip_output = zip_output
-    @property
-    def update_last_saved_time_property(self):
-        """Gets the update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :return: The update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_last_saved_time_property
-
-    @update_last_saved_time_property.setter
-    def update_last_saved_time_property(self, update_last_saved_time_property):
-        """Sets the update_last_saved_time_property of this OoxmlSaveOptionsData.
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :param update_last_saved_time_property: The update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_last_saved_time_property = update_last_saved_time_property
-    @property
-    def update_sdt_content(self):
-        """Gets the update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :return: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_sdt_content
-
-    @update_sdt_content.setter
-    def update_sdt_content(self, update_sdt_content):
-        """Sets the update_sdt_content of this OoxmlSaveOptionsData.
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :param update_sdt_content: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_sdt_content = update_sdt_content
     @property
     def update_fields(self):
         """Gets the update_fields of this OoxmlSaveOptionsData.  # noqa: E501
 
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
 
         :return: The update_fields of this OoxmlSaveOptionsData.  # noqa: E501
         :rtype: bool
@@ -279,41 +255,13 @@ class OoxmlSaveOptionsData(object):
     def update_fields(self, update_fields):
         """Sets the update_fields of this OoxmlSaveOptionsData.
 
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
 
         :param update_fields: The update_fields of this OoxmlSaveOptionsData.  # noqa: E501
         :type: bool
         """
         self._update_fields = update_fields
-    @property
-    def dml3_d_effects_rendering_mode(self):
-        """Gets the dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
 
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :return: The dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml3_d_effects_rendering_mode
-
-    @dml3_d_effects_rendering_mode.setter
-    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
-        """Sets the dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.
-
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this OoxmlSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Basic", "Advanced"]  # noqa: E501
-        if not dml3_d_effects_rendering_mode.isdigit():	
-            if dml3_d_effects_rendering_mode not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
-                    .format(dml3_d_effects_rendering_mode, allowed_values))
-            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        else:
-            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
     @property
     def update_last_printed_property(self):
         """Gets the update_last_printed_property of this OoxmlSaveOptionsData.  # noqa: E501
@@ -335,6 +283,73 @@ class OoxmlSaveOptionsData(object):
         :type: bool
         """
         self._update_last_printed_property = update_last_printed_property
+
+    @property
+    def update_last_saved_time_property(self):
+        """Gets the update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :return: The update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_last_saved_time_property
+
+    @update_last_saved_time_property.setter
+    def update_last_saved_time_property(self, update_last_saved_time_property):
+        """Sets the update_last_saved_time_property of this OoxmlSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :param update_last_saved_time_property: The update_last_saved_time_property of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_last_saved_time_property = update_last_saved_time_property
+
+    @property
+    def update_sdt_content(self):
+        """Gets the update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :return: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_sdt_content
+
+    @update_sdt_content.setter
+    def update_sdt_content(self, update_sdt_content):
+        """Sets the update_sdt_content of this OoxmlSaveOptionsData.
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :param update_sdt_content: The update_sdt_content of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_sdt_content = update_sdt_content
+
+    @property
+    def zip_output(self):
+        """Gets the zip_output of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :return: The zip_output of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._zip_output
+
+    @zip_output.setter
+    def zip_output(self, zip_output):
+        """Sets the zip_output of this OoxmlSaveOptionsData.
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :param zip_output: The zip_output of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._zip_output = zip_output
+
     @property
     def compliance(self):
         """Gets the compliance of this OoxmlSaveOptionsData.  # noqa: E501
@@ -356,6 +371,37 @@ class OoxmlSaveOptionsData(object):
         :type: str
         """
         self._compliance = compliance
+
+    @property
+    def compression_level(self):
+        """Gets the compression_level of this OoxmlSaveOptionsData.  # noqa: E501
+
+        Gets or sets compression level.  # noqa: E501
+
+        :return: The compression_level of this OoxmlSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._compression_level
+
+    @compression_level.setter
+    def compression_level(self, compression_level):
+        """Sets the compression_level of this OoxmlSaveOptionsData.
+
+        Gets or sets compression level.  # noqa: E501
+
+        :param compression_level: The compression_level of this OoxmlSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Normal", "Maximum", "Fast", "SuperFast"]  # noqa: E501
+        if not compression_level.isdigit():
+            if compression_level not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `compression_level` ({0}), must be one of {1}"  # noqa: E501
+                    .format(compression_level, allowed_values))
+            self._compression_level = compression_level
+        else:
+            self._compression_level = allowed_values[int(compression_level) if six.PY3 else long(compression_level)]
+
     @property
     def password(self):
         """Gets the password of this OoxmlSaveOptionsData.  # noqa: E501
@@ -377,6 +423,7 @@ class OoxmlSaveOptionsData(object):
         :type: str
         """
         self._password = password
+
     @property
     def pretty_format(self):
         """Gets the pretty_format of this OoxmlSaveOptionsData.  # noqa: E501
@@ -398,6 +445,8 @@ class OoxmlSaveOptionsData(object):
         :type: bool
         """
         self._pretty_format = pretty_format
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -439,4 +488,4 @@ class OoxmlSaveOptionsData(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
