@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="PageSetup.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="page_setup.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -30,7 +30,7 @@ import six
 
 
 class PageSetup(object):
-    """Represents the page setup properties of a section.             
+    """Represents the page setup properties of a section.
     """
 
     """
@@ -74,7 +74,7 @@ class PageSetup(object):
     }
 
     attribute_map = {
-        'link': 'link',
+        'link': 'Link',
         'bidi': 'Bidi',
         'border_always_in_front': 'BorderAlwaysInFront',
         'border_applies_to': 'BorderAppliesTo',
@@ -206,7 +206,7 @@ class PageSetup(object):
     def link(self):
         """Gets the link of this PageSetup.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this PageSetup.  # noqa: E501
         :rtype: WordsApiLink
@@ -217,17 +217,18 @@ class PageSetup(object):
     def link(self, link):
         """Sets the link of this PageSetup.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this PageSetup.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
     @property
     def bidi(self):
         """Gets the bidi of this PageSetup.  # noqa: E501
 
-        Gets or sets specifies that this section contains bidirectional (complex scripts) text.               # noqa: E501
+        Gets or sets specifies that this section contains bidirectional (complex scripts) text.  # noqa: E501
 
         :return: The bidi of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -238,17 +239,18 @@ class PageSetup(object):
     def bidi(self, bidi):
         """Sets the bidi of this PageSetup.
 
-        Gets or sets specifies that this section contains bidirectional (complex scripts) text.               # noqa: E501
+        Gets or sets specifies that this section contains bidirectional (complex scripts) text.  # noqa: E501
 
         :param bidi: The bidi of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._bidi = bidi
+
     @property
     def border_always_in_front(self):
         """Gets the border_always_in_front of this PageSetup.  # noqa: E501
 
-        Gets or sets specifies where the page border is positioned relative to intersecting texts and objects.               # noqa: E501
+        Gets or sets specifies where the page border is positioned relative to intersecting texts and objects.  # noqa: E501
 
         :return: The border_always_in_front of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -259,17 +261,18 @@ class PageSetup(object):
     def border_always_in_front(self, border_always_in_front):
         """Sets the border_always_in_front of this PageSetup.
 
-        Gets or sets specifies where the page border is positioned relative to intersecting texts and objects.               # noqa: E501
+        Gets or sets specifies where the page border is positioned relative to intersecting texts and objects.  # noqa: E501
 
         :param border_always_in_front: The border_always_in_front of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._border_always_in_front = border_always_in_front
+
     @property
     def border_applies_to(self):
         """Gets the border_applies_to of this PageSetup.  # noqa: E501
 
-        Gets or sets specifies which pages the page border is printed on.               # noqa: E501
+        Gets or sets specifies which pages the page border is printed on.  # noqa: E501
 
         :return: The border_applies_to of this PageSetup.  # noqa: E501
         :rtype: str
@@ -280,13 +283,13 @@ class PageSetup(object):
     def border_applies_to(self, border_applies_to):
         """Sets the border_applies_to of this PageSetup.
 
-        Gets or sets specifies which pages the page border is printed on.               # noqa: E501
+        Gets or sets specifies which pages the page border is printed on.  # noqa: E501
 
         :param border_applies_to: The border_applies_to of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["AllPages", "FirstPage", "OtherPages"]  # noqa: E501
-        if not border_applies_to.isdigit():	
+        if not border_applies_to.isdigit():
             if border_applies_to not in allowed_values:
                 raise ValueError(
                     "Invalid value for `border_applies_to` ({0}), must be one of {1}"  # noqa: E501
@@ -294,11 +297,12 @@ class PageSetup(object):
             self._border_applies_to = border_applies_to
         else:
             self._border_applies_to = allowed_values[int(border_applies_to) if six.PY3 else long(border_applies_to)]
+
     @property
     def border_distance_from(self):
         """Gets the border_distance_from of this PageSetup.  # noqa: E501
 
-        Gets or sets a value that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.               # noqa: E501
+        Gets or sets a value that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501
 
         :return: The border_distance_from of this PageSetup.  # noqa: E501
         :rtype: str
@@ -309,13 +313,13 @@ class PageSetup(object):
     def border_distance_from(self, border_distance_from):
         """Sets the border_distance_from of this PageSetup.
 
-        Gets or sets a value that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.               # noqa: E501
+        Gets or sets a value that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501
 
         :param border_distance_from: The border_distance_from of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["Text", "PageEdge"]  # noqa: E501
-        if not border_distance_from.isdigit():	
+        if not border_distance_from.isdigit():
             if border_distance_from not in allowed_values:
                 raise ValueError(
                     "Invalid value for `border_distance_from` ({0}), must be one of {1}"  # noqa: E501
@@ -323,11 +327,12 @@ class PageSetup(object):
             self._border_distance_from = border_distance_from
         else:
             self._border_distance_from = allowed_values[int(border_distance_from) if six.PY3 else long(border_distance_from)]
+
     @property
     def bottom_margin(self):
         """Gets the bottom_margin of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501
 
         :return: The bottom_margin of this PageSetup.  # noqa: E501
         :rtype: float
@@ -338,17 +343,18 @@ class PageSetup(object):
     def bottom_margin(self, bottom_margin):
         """Sets the bottom_margin of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501
 
         :param bottom_margin: The bottom_margin of this PageSetup.  # noqa: E501
         :type: float
         """
         self._bottom_margin = bottom_margin
+
     @property
     def different_first_page_header_footer(self):
         """Gets the different_first_page_header_footer of this PageSetup.  # noqa: E501
 
-        Gets or sets true if a different header or footer is used on the first page.               # noqa: E501
+        Gets or sets true if a different header or footer is used on the first page.  # noqa: E501
 
         :return: The different_first_page_header_footer of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -359,17 +365,18 @@ class PageSetup(object):
     def different_first_page_header_footer(self, different_first_page_header_footer):
         """Sets the different_first_page_header_footer of this PageSetup.
 
-        Gets or sets true if a different header or footer is used on the first page.               # noqa: E501
+        Gets or sets true if a different header or footer is used on the first page.  # noqa: E501
 
         :param different_first_page_header_footer: The different_first_page_header_footer of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._different_first_page_header_footer = different_first_page_header_footer
+
     @property
     def first_page_tray(self):
         """Gets the first_page_tray of this PageSetup.  # noqa: E501
 
-        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.               # noqa: E501
+        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501
 
         :return: The first_page_tray of this PageSetup.  # noqa: E501
         :rtype: int
@@ -380,17 +387,18 @@ class PageSetup(object):
     def first_page_tray(self, first_page_tray):
         """Sets the first_page_tray of this PageSetup.
 
-        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.               # noqa: E501
+        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501
 
         :param first_page_tray: The first_page_tray of this PageSetup.  # noqa: E501
         :type: int
         """
         self._first_page_tray = first_page_tray
+
     @property
     def footer_distance(self):
         """Gets the footer_distance of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the footer and the bottom of the page.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501
 
         :return: The footer_distance of this PageSetup.  # noqa: E501
         :rtype: float
@@ -401,17 +409,18 @@ class PageSetup(object):
     def footer_distance(self, footer_distance):
         """Sets the footer_distance of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the footer and the bottom of the page.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501
 
         :param footer_distance: The footer_distance of this PageSetup.  # noqa: E501
         :type: float
         """
         self._footer_distance = footer_distance
+
     @property
     def gutter(self):
         """Gets the gutter of this PageSetup.  # noqa: E501
 
-        Gets or sets the amount of extra space added to the margin for document binding.               # noqa: E501
+        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501
 
         :return: The gutter of this PageSetup.  # noqa: E501
         :rtype: float
@@ -422,17 +431,18 @@ class PageSetup(object):
     def gutter(self, gutter):
         """Sets the gutter of this PageSetup.
 
-        Gets or sets the amount of extra space added to the margin for document binding.               # noqa: E501
+        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501
 
         :param gutter: The gutter of this PageSetup.  # noqa: E501
         :type: float
         """
         self._gutter = gutter
+
     @property
     def header_distance(self):
         """Gets the header_distance of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the header and the top of the page.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the header and the top of the page.  # noqa: E501
 
         :return: The header_distance of this PageSetup.  # noqa: E501
         :rtype: float
@@ -443,17 +453,18 @@ class PageSetup(object):
     def header_distance(self, header_distance):
         """Sets the header_distance of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the header and the top of the page.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the header and the top of the page.  # noqa: E501
 
         :param header_distance: The header_distance of this PageSetup.  # noqa: E501
         :type: float
         """
         self._header_distance = header_distance
+
     @property
     def left_margin(self):
         """Gets the left_margin of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the left edge of the page and the left boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501
 
         :return: The left_margin of this PageSetup.  # noqa: E501
         :rtype: float
@@ -464,17 +475,18 @@ class PageSetup(object):
     def left_margin(self, left_margin):
         """Sets the left_margin of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the left edge of the page and the left boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501
 
         :param left_margin: The left_margin of this PageSetup.  # noqa: E501
         :type: float
         """
         self._left_margin = left_margin
+
     @property
     def line_number_count_by(self):
         """Gets the line_number_count_by of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the numeric increment for line numbers.               # noqa: E501
+        Gets or sets returns or sets the numeric increment for line numbers.  # noqa: E501
 
         :return: The line_number_count_by of this PageSetup.  # noqa: E501
         :rtype: int
@@ -485,17 +497,18 @@ class PageSetup(object):
     def line_number_count_by(self, line_number_count_by):
         """Sets the line_number_count_by of this PageSetup.
 
-        Gets or sets returns or sets the numeric increment for line numbers.               # noqa: E501
+        Gets or sets returns or sets the numeric increment for line numbers.  # noqa: E501
 
         :param line_number_count_by: The line_number_count_by of this PageSetup.  # noqa: E501
         :type: int
         """
         self._line_number_count_by = line_number_count_by
+
     @property
     def line_number_distance_from_text(self):
         """Gets the line_number_distance_from_text of this PageSetup.  # noqa: E501
 
-        Gets or sets distance between the right edge of line numbers and the left edge of the document.               # noqa: E501
+        Gets or sets distance between the right edge of line numbers and the left edge of the document.  # noqa: E501
 
         :return: The line_number_distance_from_text of this PageSetup.  # noqa: E501
         :rtype: float
@@ -506,17 +519,18 @@ class PageSetup(object):
     def line_number_distance_from_text(self, line_number_distance_from_text):
         """Sets the line_number_distance_from_text of this PageSetup.
 
-        Gets or sets distance between the right edge of line numbers and the left edge of the document.               # noqa: E501
+        Gets or sets distance between the right edge of line numbers and the left edge of the document.  # noqa: E501
 
         :param line_number_distance_from_text: The line_number_distance_from_text of this PageSetup.  # noqa: E501
         :type: float
         """
         self._line_number_distance_from_text = line_number_distance_from_text
+
     @property
     def line_number_restart_mode(self):
         """Gets the line_number_restart_mode of this PageSetup.  # noqa: E501
 
-        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.               # noqa: E501
+        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501
 
         :return: The line_number_restart_mode of this PageSetup.  # noqa: E501
         :rtype: str
@@ -527,13 +541,13 @@ class PageSetup(object):
     def line_number_restart_mode(self, line_number_restart_mode):
         """Sets the line_number_restart_mode of this PageSetup.
 
-        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.               # noqa: E501
+        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501
 
         :param line_number_restart_mode: The line_number_restart_mode of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["RestartPage", "RestartSection", "Continuous"]  # noqa: E501
-        if not line_number_restart_mode.isdigit():	
+        if not line_number_restart_mode.isdigit():
             if line_number_restart_mode not in allowed_values:
                 raise ValueError(
                     "Invalid value for `line_number_restart_mode` ({0}), must be one of {1}"  # noqa: E501
@@ -541,11 +555,12 @@ class PageSetup(object):
             self._line_number_restart_mode = line_number_restart_mode
         else:
             self._line_number_restart_mode = allowed_values[int(line_number_restart_mode) if six.PY3 else long(line_number_restart_mode)]
+
     @property
     def line_starting_number(self):
         """Gets the line_starting_number of this PageSetup.  # noqa: E501
 
-        Gets or sets the starting line number.               # noqa: E501
+        Gets or sets the starting line number.  # noqa: E501
 
         :return: The line_starting_number of this PageSetup.  # noqa: E501
         :rtype: int
@@ -556,17 +571,18 @@ class PageSetup(object):
     def line_starting_number(self, line_starting_number):
         """Sets the line_starting_number of this PageSetup.
 
-        Gets or sets the starting line number.               # noqa: E501
+        Gets or sets the starting line number.  # noqa: E501
 
         :param line_starting_number: The line_starting_number of this PageSetup.  # noqa: E501
         :type: int
         """
         self._line_starting_number = line_starting_number
+
     @property
     def orientation(self):
         """Gets the orientation of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the orientation of the page.               # noqa: E501
+        Gets or sets returns or sets the orientation of the page.  # noqa: E501
 
         :return: The orientation of this PageSetup.  # noqa: E501
         :rtype: str
@@ -577,13 +593,13 @@ class PageSetup(object):
     def orientation(self, orientation):
         """Sets the orientation of this PageSetup.
 
-        Gets or sets returns or sets the orientation of the page.               # noqa: E501
+        Gets or sets returns or sets the orientation of the page.  # noqa: E501
 
         :param orientation: The orientation of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["Portrait", "Landscape"]  # noqa: E501
-        if not orientation.isdigit():	
+        if not orientation.isdigit():
             if orientation not in allowed_values:
                 raise ValueError(
                     "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
@@ -591,11 +607,12 @@ class PageSetup(object):
             self._orientation = orientation
         else:
             self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]
+
     @property
     def other_pages_tray(self):
         """Gets the other_pages_tray of this PageSetup.  # noqa: E501
 
-        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.               # noqa: E501
+        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501
 
         :return: The other_pages_tray of this PageSetup.  # noqa: E501
         :rtype: int
@@ -606,17 +623,18 @@ class PageSetup(object):
     def other_pages_tray(self, other_pages_tray):
         """Sets the other_pages_tray of this PageSetup.
 
-        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.               # noqa: E501
+        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501
 
         :param other_pages_tray: The other_pages_tray of this PageSetup.  # noqa: E501
         :type: int
         """
         self._other_pages_tray = other_pages_tray
+
     @property
     def page_height(self):
         """Gets the page_height of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the height of the page in points.               # noqa: E501
+        Gets or sets returns or sets the height of the page in points.  # noqa: E501
 
         :return: The page_height of this PageSetup.  # noqa: E501
         :rtype: float
@@ -627,17 +645,18 @@ class PageSetup(object):
     def page_height(self, page_height):
         """Sets the page_height of this PageSetup.
 
-        Gets or sets returns or sets the height of the page in points.               # noqa: E501
+        Gets or sets returns or sets the height of the page in points.  # noqa: E501
 
         :param page_height: The page_height of this PageSetup.  # noqa: E501
         :type: float
         """
         self._page_height = page_height
+
     @property
     def page_number_style(self):
         """Gets the page_number_style of this PageSetup.  # noqa: E501
 
-        Gets or sets the page number format.               # noqa: E501
+        Gets or sets the page number format.  # noqa: E501
 
         :return: The page_number_style of this PageSetup.  # noqa: E501
         :rtype: str
@@ -648,13 +667,13 @@ class PageSetup(object):
     def page_number_style(self, page_number_style):
         """Sets the page_number_style of this PageSetup.
 
-        Gets or sets the page number format.               # noqa: E501
+        Gets or sets the page number format.  # noqa: E501
 
         :param page_number_style: The page_number_style of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
-        if not page_number_style.isdigit():	
+        if not page_number_style.isdigit():
             if page_number_style not in allowed_values:
                 raise ValueError(
                     "Invalid value for `page_number_style` ({0}), must be one of {1}"  # noqa: E501
@@ -662,11 +681,12 @@ class PageSetup(object):
             self._page_number_style = page_number_style
         else:
             self._page_number_style = allowed_values[int(page_number_style) if six.PY3 else long(page_number_style)]
+
     @property
     def page_starting_number(self):
         """Gets the page_starting_number of this PageSetup.  # noqa: E501
 
-        Gets or sets the starting page number of the section.               # noqa: E501
+        Gets or sets the starting page number of the section.  # noqa: E501
 
         :return: The page_starting_number of this PageSetup.  # noqa: E501
         :rtype: int
@@ -677,17 +697,18 @@ class PageSetup(object):
     def page_starting_number(self, page_starting_number):
         """Sets the page_starting_number of this PageSetup.
 
-        Gets or sets the starting page number of the section.               # noqa: E501
+        Gets or sets the starting page number of the section.  # noqa: E501
 
         :param page_starting_number: The page_starting_number of this PageSetup.  # noqa: E501
         :type: int
         """
         self._page_starting_number = page_starting_number
+
     @property
     def page_width(self):
         """Gets the page_width of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the width of the page in points.               # noqa: E501
+        Gets or sets returns or sets the width of the page in points.  # noqa: E501
 
         :return: The page_width of this PageSetup.  # noqa: E501
         :rtype: float
@@ -698,17 +719,18 @@ class PageSetup(object):
     def page_width(self, page_width):
         """Sets the page_width of this PageSetup.
 
-        Gets or sets returns or sets the width of the page in points.               # noqa: E501
+        Gets or sets returns or sets the width of the page in points.  # noqa: E501
 
         :param page_width: The page_width of this PageSetup.  # noqa: E501
         :type: float
         """
         self._page_width = page_width
+
     @property
     def paper_size(self):
         """Gets the paper_size of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the paper size.               # noqa: E501
+        Gets or sets returns or sets the paper size.  # noqa: E501
 
         :return: The paper_size of this PageSetup.  # noqa: E501
         :rtype: str
@@ -719,13 +741,13 @@ class PageSetup(object):
     def paper_size(self, paper_size):
         """Sets the paper_size of this PageSetup.
 
-        Gets or sets returns or sets the paper size.               # noqa: E501
+        Gets or sets returns or sets the paper size.  # noqa: E501
 
         :param paper_size: The paper_size of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["A3", "A4", "A5", "B4", "B5", "Executive", "Folio", "Ledger", "Legal", "Letter", "EnvelopeDL", "Quarto", "Statement", "Tabloid", "Paper10x14", "Paper11x17", "Custom"]  # noqa: E501
-        if not paper_size.isdigit():	
+        if not paper_size.isdigit():
             if paper_size not in allowed_values:
                 raise ValueError(
                     "Invalid value for `paper_size` ({0}), must be one of {1}"  # noqa: E501
@@ -733,11 +755,12 @@ class PageSetup(object):
             self._paper_size = paper_size
         else:
             self._paper_size = allowed_values[int(paper_size) if six.PY3 else long(paper_size)]
+
     @property
     def restart_page_numbering(self):
         """Gets the restart_page_numbering of this PageSetup.  # noqa: E501
 
-        Gets or sets true if page numbering restarts at the beginning of the section.               # noqa: E501
+        Gets or sets true if page numbering restarts at the beginning of the section.  # noqa: E501
 
         :return: The restart_page_numbering of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -748,17 +771,18 @@ class PageSetup(object):
     def restart_page_numbering(self, restart_page_numbering):
         """Sets the restart_page_numbering of this PageSetup.
 
-        Gets or sets true if page numbering restarts at the beginning of the section.               # noqa: E501
+        Gets or sets true if page numbering restarts at the beginning of the section.  # noqa: E501
 
         :param restart_page_numbering: The restart_page_numbering of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._restart_page_numbering = restart_page_numbering
+
     @property
     def right_margin(self):
         """Gets the right_margin of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the right edge of the page and the right boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501
 
         :return: The right_margin of this PageSetup.  # noqa: E501
         :rtype: float
@@ -769,17 +793,18 @@ class PageSetup(object):
     def right_margin(self, right_margin):
         """Sets the right_margin of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the right edge of the page and the right boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501
 
         :param right_margin: The right_margin of this PageSetup.  # noqa: E501
         :type: float
         """
         self._right_margin = right_margin
+
     @property
     def rtl_gutter(self):
         """Gets the rtl_gutter of this PageSetup.  # noqa: E501
 
-        Gets or sets whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.               # noqa: E501
+        Gets or sets whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501
 
         :return: The rtl_gutter of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -790,17 +815,18 @@ class PageSetup(object):
     def rtl_gutter(self, rtl_gutter):
         """Sets the rtl_gutter of this PageSetup.
 
-        Gets or sets whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.               # noqa: E501
+        Gets or sets whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501
 
         :param rtl_gutter: The rtl_gutter of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._rtl_gutter = rtl_gutter
+
     @property
     def section_start(self):
         """Gets the section_start of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the type of section break for the specified object.               # noqa: E501
+        Gets or sets returns or sets the type of section break for the specified object.  # noqa: E501
 
         :return: The section_start of this PageSetup.  # noqa: E501
         :rtype: str
@@ -811,13 +837,13 @@ class PageSetup(object):
     def section_start(self, section_start):
         """Sets the section_start of this PageSetup.
 
-        Gets or sets returns or sets the type of section break for the specified object.               # noqa: E501
+        Gets or sets returns or sets the type of section break for the specified object.  # noqa: E501
 
         :param section_start: The section_start of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["Continuous", "NewColumn", "NewPage", "EvenPage", "OddPage"]  # noqa: E501
-        if not section_start.isdigit():	
+        if not section_start.isdigit():
             if section_start not in allowed_values:
                 raise ValueError(
                     "Invalid value for `section_start` ({0}), must be one of {1}"  # noqa: E501
@@ -825,11 +851,12 @@ class PageSetup(object):
             self._section_start = section_start
         else:
             self._section_start = allowed_values[int(section_start) if six.PY3 else long(section_start)]
+
     @property
     def suppress_endnotes(self):
         """Gets the suppress_endnotes of this PageSetup.  # noqa: E501
 
-        Gets or sets true if endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.               # noqa: E501
+        Gets or sets true if endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501
 
         :return: The suppress_endnotes of this PageSetup.  # noqa: E501
         :rtype: bool
@@ -840,17 +867,18 @@ class PageSetup(object):
     def suppress_endnotes(self, suppress_endnotes):
         """Sets the suppress_endnotes of this PageSetup.
 
-        Gets or sets true if endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.               # noqa: E501
+        Gets or sets true if endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501
 
         :param suppress_endnotes: The suppress_endnotes of this PageSetup.  # noqa: E501
         :type: bool
         """
         self._suppress_endnotes = suppress_endnotes
+
     @property
     def top_margin(self):
         """Gets the top_margin of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the distance (in points) between the top edge of the page and the top boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501
 
         :return: The top_margin of this PageSetup.  # noqa: E501
         :rtype: float
@@ -861,17 +889,18 @@ class PageSetup(object):
     def top_margin(self, top_margin):
         """Sets the top_margin of this PageSetup.
 
-        Gets or sets returns or sets the distance (in points) between the top edge of the page and the top boundary of the body text.               # noqa: E501
+        Gets or sets returns or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501
 
         :param top_margin: The top_margin of this PageSetup.  # noqa: E501
         :type: float
         """
         self._top_margin = top_margin
+
     @property
     def vertical_alignment(self):
         """Gets the vertical_alignment of this PageSetup.  # noqa: E501
 
-        Gets or sets returns or sets the vertical alignment of text on each page in a document or section.               # noqa: E501
+        Gets or sets returns or sets the vertical alignment of text on each page in a document or section.  # noqa: E501
 
         :return: The vertical_alignment of this PageSetup.  # noqa: E501
         :rtype: str
@@ -882,13 +911,13 @@ class PageSetup(object):
     def vertical_alignment(self, vertical_alignment):
         """Sets the vertical_alignment of this PageSetup.
 
-        Gets or sets returns or sets the vertical alignment of text on each page in a document or section.               # noqa: E501
+        Gets or sets returns or sets the vertical alignment of text on each page in a document or section.  # noqa: E501
 
         :param vertical_alignment: The vertical_alignment of this PageSetup.  # noqa: E501
         :type: str
         """
         allowed_values = ["Top", "Center", "Justify", "Bottom"]  # noqa: E501
-        if not vertical_alignment.isdigit():	
+        if not vertical_alignment.isdigit():
             if vertical_alignment not in allowed_values:
                 raise ValueError(
                     "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
@@ -896,6 +925,8 @@ class PageSetup(object):
             self._vertical_alignment = vertical_alignment
         else:
             self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -937,4 +968,4 @@ class PageSetup(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
