@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="RevisionsModificationResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="revisions_modification_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,11 +83,12 @@ class RevisionsModificationResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def result(self):
         """Gets the result of this RevisionsModificationResponse.  # noqa: E501
 
-        Gets or sets result.  # noqa: E501
+        Gets or sets result of the modification operations for the revisions collection.  # noqa: E501
 
         :return: The result of this RevisionsModificationResponse.  # noqa: E501
         :rtype: ModificationOperationResult
@@ -98,12 +99,14 @@ class RevisionsModificationResponse(object):
     def result(self, result):
         """Sets the result of this RevisionsModificationResponse.
 
-        Gets or sets result.  # noqa: E501
+        Gets or sets result of the modification operations for the revisions collection.  # noqa: E501
 
         :param result: The result of this RevisionsModificationResponse.  # noqa: E501
         :type: ModificationOperationResult
         """
         self._result = result
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class RevisionsModificationResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
