@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="Section.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="section.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -50,7 +50,7 @@ class Section(object):
     }
 
     attribute_map = {
-        'link': 'link',
+        'link': 'Link',
         'child_nodes': 'ChildNodes',
         'header_footers': 'HeaderFooters',
         'page_setup': 'PageSetup',
@@ -86,7 +86,7 @@ class Section(object):
     def link(self):
         """Gets the link of this Section.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this Section.  # noqa: E501
         :rtype: WordsApiLink
@@ -97,12 +97,13 @@ class Section(object):
     def link(self, link):
         """Sets the link of this Section.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this Section.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
     @property
     def child_nodes(self):
         """Gets the child_nodes of this Section.  # noqa: E501
@@ -124,11 +125,12 @@ class Section(object):
         :type: list[NodeLink]
         """
         self._child_nodes = child_nodes
+
     @property
     def header_footers(self):
         """Gets the header_footers of this Section.  # noqa: E501
 
-        Gets or sets header_footers.  # noqa: E501
+        Gets or sets link to HeaderFooters resource.  # noqa: E501
 
         :return: The header_footers of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -139,17 +141,18 @@ class Section(object):
     def header_footers(self, header_footers):
         """Sets the header_footers of this Section.
 
-        Gets or sets header_footers.  # noqa: E501
+        Gets or sets link to HeaderFooters resource.  # noqa: E501
 
         :param header_footers: The header_footers of this Section.  # noqa: E501
         :type: LinkElement
         """
         self._header_footers = header_footers
+
     @property
     def page_setup(self):
         """Gets the page_setup of this Section.  # noqa: E501
 
-        Gets or sets page_setup.  # noqa: E501
+        Gets or sets link to PageSetup resource.  # noqa: E501
 
         :return: The page_setup of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -160,17 +163,18 @@ class Section(object):
     def page_setup(self, page_setup):
         """Sets the page_setup of this Section.
 
-        Gets or sets page_setup.  # noqa: E501
+        Gets or sets link to PageSetup resource.  # noqa: E501
 
         :param page_setup: The page_setup of this Section.  # noqa: E501
         :type: LinkElement
         """
         self._page_setup = page_setup
+
     @property
     def paragraphs(self):
         """Gets the paragraphs of this Section.  # noqa: E501
 
-        Gets or sets paragraphs.  # noqa: E501
+        Gets or sets link to Paragraphs resource.  # noqa: E501
 
         :return: The paragraphs of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -181,17 +185,18 @@ class Section(object):
     def paragraphs(self, paragraphs):
         """Sets the paragraphs of this Section.
 
-        Gets or sets paragraphs.  # noqa: E501
+        Gets or sets link to Paragraphs resource.  # noqa: E501
 
         :param paragraphs: The paragraphs of this Section.  # noqa: E501
         :type: LinkElement
         """
         self._paragraphs = paragraphs
+
     @property
     def tables(self):
         """Gets the tables of this Section.  # noqa: E501
 
-        Gets or sets tables.  # noqa: E501
+        Gets or sets link to Tables resource.  # noqa: E501
 
         :return: The tables of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -202,12 +207,14 @@ class Section(object):
     def tables(self, tables):
         """Sets the tables of this Section.
 
-        Gets or sets tables.  # noqa: E501
+        Gets or sets link to Tables resource.  # noqa: E501
 
         :param tables: The tables of this Section.  # noqa: E501
         :type: LinkElement
         """
         self._tables = tables
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -249,4 +256,4 @@ class Section(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
