@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="SectionLinkCollectionResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="section_link_collection_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -83,11 +83,12 @@ class SectionLinkCollectionResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def sections(self):
         """Gets the sections of this SectionLinkCollectionResponse.  # noqa: E501
 
-        Gets or sets sections.  # noqa: E501
+        Gets or sets collection of sections.  # noqa: E501
 
         :return: The sections of this SectionLinkCollectionResponse.  # noqa: E501
         :rtype: SectionLinkCollection
@@ -98,12 +99,14 @@ class SectionLinkCollectionResponse(object):
     def sections(self, sections):
         """Sets the sections of this SectionLinkCollectionResponse.
 
-        Gets or sets sections.  # noqa: E501
+        Gets or sets collection of sections.  # noqa: E501
 
         :param sections: The sections of this SectionLinkCollectionResponse.  # noqa: E501
         :type: SectionLinkCollection
         """
         self._sections = sections
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class SectionLinkCollectionResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
