@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="StatDataResponse.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="stat_data_response.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -30,7 +30,7 @@ import six
 
 
 class StatDataResponse(object):
-    """Response for the request of the document&#39;s statistical data.
+    """Response for the request of the document's statistical data.
     """
 
     """
@@ -88,11 +88,12 @@ class StatDataResponse(object):
         :type: str
         """
         self._request_id = request_id
+
     @property
     def document_link(self):
         """Gets the document_link of this StatDataResponse.  # noqa: E501
 
-        Gets or sets document_link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The document_link of this StatDataResponse.  # noqa: E501
         :rtype: FileLink
@@ -103,17 +104,18 @@ class StatDataResponse(object):
     def document_link(self, document_link):
         """Sets the document_link of this StatDataResponse.
 
-        Gets or sets document_link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param document_link: The document_link of this StatDataResponse.  # noqa: E501
         :type: FileLink
         """
         self._document_link = document_link
+
     @property
     def stat_data(self):
         """Gets the stat_data of this StatDataResponse.  # noqa: E501
 
-        Gets or sets stat_data.  # noqa: E501
+        Gets or sets statistical data of the document.  # noqa: E501
 
         :return: The stat_data of this StatDataResponse.  # noqa: E501
         :rtype: DocumentStatData
@@ -124,12 +126,14 @@ class StatDataResponse(object):
     def stat_data(self, stat_data):
         """Sets the stat_data of this StatDataResponse.
 
-        Gets or sets stat_data.  # noqa: E501
+        Gets or sets statistical data of the document.  # noqa: E501
 
         :param stat_data: The stat_data of this StatDataResponse.  # noqa: E501
         :type: DocumentStatData
         """
         self._stat_data = stat_data
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -171,4 +175,4 @@ class StatDataResponse(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
