@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="TableCellFormat.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="table_cell_format.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -57,7 +57,7 @@ class TableCellFormat(object):
     }
 
     attribute_map = {
-        'link': 'link',
+        'link': 'Link',
         'bottom_padding': 'BottomPadding',
         'fit_text': 'FitText',
         'horizontal_merge': 'HorizontalMerge',
@@ -121,7 +121,7 @@ class TableCellFormat(object):
     def link(self):
         """Gets the link of this TableCellFormat.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :return: The link of this TableCellFormat.  # noqa: E501
         :rtype: WordsApiLink
@@ -132,12 +132,13 @@ class TableCellFormat(object):
     def link(self, link):
         """Sets the link of this TableCellFormat.
 
-        Gets or sets link.  # noqa: E501
+        Gets or sets link to the document.  # noqa: E501
 
         :param link: The link of this TableCellFormat.  # noqa: E501
         :type: WordsApiLink
         """
         self._link = link
+
     @property
     def bottom_padding(self):
         """Gets the bottom_padding of this TableCellFormat.  # noqa: E501
@@ -159,6 +160,7 @@ class TableCellFormat(object):
         :type: float
         """
         self._bottom_padding = bottom_padding
+
     @property
     def fit_text(self):
         """Gets the fit_text of this TableCellFormat.  # noqa: E501
@@ -180,6 +182,7 @@ class TableCellFormat(object):
         :type: bool
         """
         self._fit_text = fit_text
+
     @property
     def horizontal_merge(self):
         """Gets the horizontal_merge of this TableCellFormat.  # noqa: E501
@@ -201,7 +204,7 @@ class TableCellFormat(object):
         :type: str
         """
         allowed_values = ["None", "First", "Previous"]  # noqa: E501
-        if not horizontal_merge.isdigit():	
+        if not horizontal_merge.isdigit():
             if horizontal_merge not in allowed_values:
                 raise ValueError(
                     "Invalid value for `horizontal_merge` ({0}), must be one of {1}"  # noqa: E501
@@ -209,6 +212,7 @@ class TableCellFormat(object):
             self._horizontal_merge = horizontal_merge
         else:
             self._horizontal_merge = allowed_values[int(horizontal_merge) if six.PY3 else long(horizontal_merge)]
+
     @property
     def left_padding(self):
         """Gets the left_padding of this TableCellFormat.  # noqa: E501
@@ -230,6 +234,7 @@ class TableCellFormat(object):
         :type: float
         """
         self._left_padding = left_padding
+
     @property
     def orientation(self):
         """Gets the orientation of this TableCellFormat.  # noqa: E501
@@ -251,7 +256,7 @@ class TableCellFormat(object):
         :type: str
         """
         allowed_values = ["Horizontal", "Downward", "Upward", "HorizontalRotatedFarEast", "VerticalFarEast", "VerticalRotatedFarEast"]  # noqa: E501
-        if not orientation.isdigit():	
+        if not orientation.isdigit():
             if orientation not in allowed_values:
                 raise ValueError(
                     "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
@@ -259,11 +264,12 @@ class TableCellFormat(object):
             self._orientation = orientation
         else:
             self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]
+
     @property
     def preferred_width(self):
         """Gets the preferred_width of this TableCellFormat.  # noqa: E501
 
-        Gets or sets preferred_width.  # noqa: E501
+        Gets or sets returns or sets the preferred width of the cell.  # noqa: E501
 
         :return: The preferred_width of this TableCellFormat.  # noqa: E501
         :rtype: PreferredWidth
@@ -274,12 +280,13 @@ class TableCellFormat(object):
     def preferred_width(self, preferred_width):
         """Sets the preferred_width of this TableCellFormat.
 
-        Gets or sets preferred_width.  # noqa: E501
+        Gets or sets returns or sets the preferred width of the cell.  # noqa: E501
 
         :param preferred_width: The preferred_width of this TableCellFormat.  # noqa: E501
         :type: PreferredWidth
         """
         self._preferred_width = preferred_width
+
     @property
     def right_padding(self):
         """Gets the right_padding of this TableCellFormat.  # noqa: E501
@@ -301,6 +308,7 @@ class TableCellFormat(object):
         :type: float
         """
         self._right_padding = right_padding
+
     @property
     def top_padding(self):
         """Gets the top_padding of this TableCellFormat.  # noqa: E501
@@ -322,6 +330,7 @@ class TableCellFormat(object):
         :type: float
         """
         self._top_padding = top_padding
+
     @property
     def vertical_alignment(self):
         """Gets the vertical_alignment of this TableCellFormat.  # noqa: E501
@@ -343,7 +352,7 @@ class TableCellFormat(object):
         :type: str
         """
         allowed_values = ["Top", "Center", "Bottom"]  # noqa: E501
-        if not vertical_alignment.isdigit():	
+        if not vertical_alignment.isdigit():
             if vertical_alignment not in allowed_values:
                 raise ValueError(
                     "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
@@ -351,6 +360,7 @@ class TableCellFormat(object):
             self._vertical_alignment = vertical_alignment
         else:
             self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]
+
     @property
     def vertical_merge(self):
         """Gets the vertical_merge of this TableCellFormat.  # noqa: E501
@@ -372,7 +382,7 @@ class TableCellFormat(object):
         :type: str
         """
         allowed_values = ["None", "First", "Previous"]  # noqa: E501
-        if not vertical_merge.isdigit():	
+        if not vertical_merge.isdigit():
             if vertical_merge not in allowed_values:
                 raise ValueError(
                     "Invalid value for `vertical_merge` ({0}), must be one of {1}"  # noqa: E501
@@ -380,6 +390,7 @@ class TableCellFormat(object):
             self._vertical_merge = vertical_merge
         else:
             self._vertical_merge = allowed_values[int(vertical_merge) if six.PY3 else long(vertical_merge)]
+
     @property
     def width(self):
         """Gets the width of this TableCellFormat.  # noqa: E501
@@ -401,6 +412,7 @@ class TableCellFormat(object):
         :type: float
         """
         self._width = width
+
     @property
     def wrap_text(self):
         """Gets the wrap_text of this TableCellFormat.  # noqa: E501
@@ -422,6 +434,8 @@ class TableCellFormat(object):
         :type: bool
         """
         self._wrap_text = wrap_text
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -463,4 +477,4 @@ class TableCellFormat(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
