@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="TableLink.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="table_link.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,26 +41,48 @@ class TableLink(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'node_id': 'str',
-        'link': 'WordsApiLink'
+        'link': 'WordsApiLink',
+        'node_id': 'str'
     }
 
     attribute_map = {
-        'node_id': 'NodeId',
-        'link': 'link'
+        'link': 'Link',
+        'node_id': 'NodeId'
     }
 
-    def __init__(self, node_id=None, link=None):  # noqa: E501
+    def __init__(self, link=None, node_id=None):  # noqa: E501
         """TableLink - a model defined in Swagger"""  # noqa: E501
 
-        self._node_id = None
         self._link = None
+        self._node_id = None
         self.discriminator = None
 
-        if node_id is not None:
-            self.node_id = node_id
         if link is not None:
             self.link = link
+        if node_id is not None:
+            self.node_id = node_id
+
+    @property
+    def link(self):
+        """Gets the link of this TableLink.  # noqa: E501
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :return: The link of this TableLink.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this TableLink.
+
+        Gets or sets link to the document.  # noqa: E501
+
+        :param link: The link of this TableLink.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
 
     @property
     def node_id(self):
@@ -83,27 +105,8 @@ class TableLink(object):
         :type: str
         """
         self._node_id = node_id
-    @property
-    def link(self):
-        """Gets the link of this TableLink.  # noqa: E501
 
-        Gets or sets link.  # noqa: E501
 
-        :return: The link of this TableLink.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this TableLink.
-
-        Gets or sets link.  # noqa: E501
-
-        :param link: The link of this TableLink.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -145,4 +148,4 @@ class TableLink(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
