@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
-# <copyright company="Aspose" file="XpsSaveOptionsData.py">
-#   Copyright (c) 2019 Aspose.Words for Cloud
+# <copyright company="Aspose" file="xps_save_options_data.py">
+#   Copyright (c) 2020 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,6 +41,16 @@ class XpsSaveOptionsData(object):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'dml3_d_effects_rendering_mode': 'str',
+        'dml_effects_rendering_mode': 'str',
+        'dml_rendering_mode': 'str',
+        'file_name': 'str',
+        'save_format': 'str',
+        'update_fields': 'bool',
+        'update_last_printed_property': 'bool',
+        'update_last_saved_time_property': 'bool',
+        'update_sdt_content': 'bool',
+        'zip_output': 'bool',
         'color_mode': 'str',
         'jpeg_quality': 'int',
         'metafile_rendering_options': 'MetafileRenderingOptionsData',
@@ -48,16 +58,6 @@ class XpsSaveOptionsData(object):
         'optimize_output': 'bool',
         'page_count': 'int',
         'page_index': 'int',
-        'save_format': 'str',
-        'file_name': 'str',
-        'dml_rendering_mode': 'str',
-        'dml_effects_rendering_mode': 'str',
-        'zip_output': 'bool',
-        'update_last_saved_time_property': 'bool',
-        'update_sdt_content': 'bool',
-        'update_fields': 'bool',
-        'dml3_d_effects_rendering_mode': 'str',
-        'update_last_printed_property': 'bool',
         'bookmarks_outline_level': 'int',
         'headings_outline_levels': 'int',
         'outline_options': 'OutlineOptionsData',
@@ -65,6 +65,16 @@ class XpsSaveOptionsData(object):
     }
 
     attribute_map = {
+        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
+        'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
+        'dml_rendering_mode': 'DmlRenderingMode',
+        'file_name': 'FileName',
+        'save_format': 'SaveFormat',
+        'update_fields': 'UpdateFields',
+        'update_last_printed_property': 'UpdateLastPrintedProperty',
+        'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
+        'update_sdt_content': 'UpdateSdtContent',
+        'zip_output': 'ZipOutput',
         'color_mode': 'ColorMode',
         'jpeg_quality': 'JpegQuality',
         'metafile_rendering_options': 'MetafileRenderingOptions',
@@ -72,25 +82,25 @@ class XpsSaveOptionsData(object):
         'optimize_output': 'OptimizeOutput',
         'page_count': 'PageCount',
         'page_index': 'PageIndex',
-        'save_format': 'SaveFormat',
-        'file_name': 'FileName',
-        'dml_rendering_mode': 'DmlRenderingMode',
-        'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
-        'zip_output': 'ZipOutput',
-        'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
-        'update_sdt_content': 'UpdateSdtContent',
-        'update_fields': 'UpdateFields',
-        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
-        'update_last_printed_property': 'UpdateLastPrintedProperty',
         'bookmarks_outline_level': 'BookmarksOutlineLevel',
         'headings_outline_levels': 'HeadingsOutlineLevels',
         'outline_options': 'OutlineOptions',
         'use_book_fold_printing_settings': 'UseBookFoldPrintingSettings'
     }
 
-    def __init__(self, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, save_format=None, file_name=None, dml_rendering_mode=None, dml_effects_rendering_mode=None, zip_output=None, update_last_saved_time_property=None, update_sdt_content=None, update_fields=None, dml3_d_effects_rendering_mode=None, update_last_printed_property=None, bookmarks_outline_level=None, headings_outline_levels=None, outline_options=None, use_book_fold_printing_settings=None):  # noqa: E501
+    def __init__(self, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, bookmarks_outline_level=None, headings_outline_levels=None, outline_options=None, use_book_fold_printing_settings=None):  # noqa: E501
         """XpsSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
+        self._dml3_d_effects_rendering_mode = None
+        self._dml_effects_rendering_mode = None
+        self._dml_rendering_mode = None
+        self._file_name = None
+        self._save_format = None
+        self._update_fields = None
+        self._update_last_printed_property = None
+        self._update_last_saved_time_property = None
+        self._update_sdt_content = None
+        self._zip_output = None
         self._color_mode = None
         self._jpeg_quality = None
         self._metafile_rendering_options = None
@@ -98,22 +108,32 @@ class XpsSaveOptionsData(object):
         self._optimize_output = None
         self._page_count = None
         self._page_index = None
-        self._save_format = None
-        self._file_name = None
-        self._dml_rendering_mode = None
-        self._dml_effects_rendering_mode = None
-        self._zip_output = None
-        self._update_last_saved_time_property = None
-        self._update_sdt_content = None
-        self._update_fields = None
-        self._dml3_d_effects_rendering_mode = None
-        self._update_last_printed_property = None
         self._bookmarks_outline_level = None
         self._headings_outline_levels = None
         self._outline_options = None
         self._use_book_fold_printing_settings = None
         self.discriminator = None
 
+        if dml3_d_effects_rendering_mode is not None:
+            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        if dml_effects_rendering_mode is not None:
+            self.dml_effects_rendering_mode = dml_effects_rendering_mode
+        if dml_rendering_mode is not None:
+            self.dml_rendering_mode = dml_rendering_mode
+        if file_name is not None:
+            self.file_name = file_name
+        if save_format is not None:
+            self.save_format = save_format
+        if update_fields is not None:
+            self.update_fields = update_fields
+        if update_last_printed_property is not None:
+            self.update_last_printed_property = update_last_printed_property
+        if update_last_saved_time_property is not None:
+            self.update_last_saved_time_property = update_last_saved_time_property
+        if update_sdt_content is not None:
+            self.update_sdt_content = update_sdt_content
+        if zip_output is not None:
+            self.zip_output = zip_output
         if color_mode is not None:
             self.color_mode = color_mode
         if jpeg_quality is not None:
@@ -128,26 +148,6 @@ class XpsSaveOptionsData(object):
             self.page_count = page_count
         if page_index is not None:
             self.page_index = page_index
-        if save_format is not None:
-            self.save_format = save_format
-        if file_name is not None:
-            self.file_name = file_name
-        if dml_rendering_mode is not None:
-            self.dml_rendering_mode = dml_rendering_mode
-        if dml_effects_rendering_mode is not None:
-            self.dml_effects_rendering_mode = dml_effects_rendering_mode
-        if zip_output is not None:
-            self.zip_output = zip_output
-        if update_last_saved_time_property is not None:
-            self.update_last_saved_time_property = update_last_saved_time_property
-        if update_sdt_content is not None:
-            self.update_sdt_content = update_sdt_content
-        if update_fields is not None:
-            self.update_fields = update_fields
-        if dml3_d_effects_rendering_mode is not None:
-            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        if update_last_printed_property is not None:
-            self.update_last_printed_property = update_last_printed_property
         if bookmarks_outline_level is not None:
             self.bookmarks_outline_level = bookmarks_outline_level
         if headings_outline_levels is not None:
@@ -157,6 +157,234 @@ class XpsSaveOptionsData(object):
         if use_book_fold_printing_settings is not None:
             self.use_book_fold_printing_settings = use_book_fold_printing_settings
 
+    @property
+    def dml3_d_effects_rendering_mode(self):
+        """Gets the dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :return: The dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml3_d_effects_rendering_mode
+
+    @dml3_d_effects_rendering_mode.setter
+    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
+        """Sets the dml3_d_effects_rendering_mode of this XpsSaveOptionsData.
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Basic", "Advanced"]  # noqa: E501
+        if not dml3_d_effects_rendering_mode.isdigit():
+            if dml3_d_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml3_d_effects_rendering_mode, allowed_values))
+            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        else:
+            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
+
+    @property
+    def dml_effects_rendering_mode(self):
+        """Gets the dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :return: The dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_effects_rendering_mode
+
+    @dml_effects_rendering_mode.setter
+    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
+        """Sets the dml_effects_rendering_mode of this XpsSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
+
+        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+
+    @property
+    def dml_rendering_mode(self):
+        """Gets the dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :return: The dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml_rendering_mode
+
+    @dml_rendering_mode.setter
+    def dml_rendering_mode(self, dml_rendering_mode):
+        """Sets the dml_rendering_mode of this XpsSaveOptionsData.
+
+        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
+
+        :param dml_rendering_mode: The dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._dml_rendering_mode = dml_rendering_mode
+
+    @property
+    def file_name(self):
+        """Gets the file_name of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :return: The file_name of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._file_name
+
+    @file_name.setter
+    def file_name(self, file_name):
+        """Sets the file_name of this XpsSaveOptionsData.
+
+        Gets or sets name of destination file.  # noqa: E501
+
+        :param file_name: The file_name of this XpsSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._file_name = file_name
+
+    @property
+    def save_format(self):
+        """Gets the save_format of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets format of save.  # noqa: E501
+
+        :return: The save_format of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._save_format
+
+    @save_format.setter
+    def save_format(self, save_format):
+        """Sets the save_format of this XpsSaveOptionsData.
+
+        Gets or sets format of save.  # noqa: E501
+
+        :param save_format: The save_format of this XpsSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        self._save_format = save_format
+
+    @property
+    def update_fields(self):
+        """Gets the update_fields of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
+
+        :return: The update_fields of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_fields
+
+    @update_fields.setter
+    def update_fields(self, update_fields):
+        """Sets the update_fields of this XpsSaveOptionsData.
+
+        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501
+
+        :param update_fields: The update_fields of this XpsSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_fields = update_fields
+
+    @property
+    def update_last_printed_property(self):
+        """Gets the update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
+
+        :return: The update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_last_printed_property
+
+    @update_last_printed_property.setter
+    def update_last_printed_property(self, update_last_printed_property):
+        """Sets the update_last_printed_property of this XpsSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
+
+        :param update_last_printed_property: The update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_last_printed_property = update_last_printed_property
+
+    @property
+    def update_last_saved_time_property(self):
+        """Gets the update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :return: The update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_last_saved_time_property
+
+    @update_last_saved_time_property.setter
+    def update_last_saved_time_property(self, update_last_saved_time_property):
+        """Sets the update_last_saved_time_property of this XpsSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
+
+        :param update_last_saved_time_property: The update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_last_saved_time_property = update_last_saved_time_property
+
+    @property
+    def update_sdt_content(self):
+        """Gets the update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :return: The update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_sdt_content
+
+    @update_sdt_content.setter
+    def update_sdt_content(self, update_sdt_content):
+        """Sets the update_sdt_content of this XpsSaveOptionsData.
+
+        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
+
+        :param update_sdt_content: The update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_sdt_content = update_sdt_content
+
+    @property
+    def zip_output(self):
+        """Gets the zip_output of this XpsSaveOptionsData.  # noqa: E501
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :return: The zip_output of this XpsSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._zip_output
+
+    @zip_output.setter
+    def zip_output(self, zip_output):
+        """Sets the zip_output of this XpsSaveOptionsData.
+
+        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
+
+        :param zip_output: The zip_output of this XpsSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._zip_output = zip_output
+
     @property
     def color_mode(self):
         """Gets the color_mode of this XpsSaveOptionsData.  # noqa: E501
@@ -178,6 +406,7 @@ class XpsSaveOptionsData(object):
         :type: str
         """
         self._color_mode = color_mode
+
     @property
     def jpeg_quality(self):
         """Gets the jpeg_quality of this XpsSaveOptionsData.  # noqa: E501
@@ -199,11 +428,12 @@ class XpsSaveOptionsData(object):
         :type: int
         """
         self._jpeg_quality = jpeg_quality
+
     @property
     def metafile_rendering_options(self):
         """Gets the metafile_rendering_options of this XpsSaveOptionsData.  # noqa: E501
 
-        Gets or sets metafile_rendering_options.  # noqa: E501
+        Gets or sets allows to specify metafile rendering options.  # noqa: E501
 
         :return: The metafile_rendering_options of this XpsSaveOptionsData.  # noqa: E501
         :rtype: MetafileRenderingOptionsData
@@ -214,12 +444,13 @@ class XpsSaveOptionsData(object):
     def metafile_rendering_options(self, metafile_rendering_options):
         """Sets the metafile_rendering_options of this XpsSaveOptionsData.
 
-        Gets or sets metafile_rendering_options.  # noqa: E501
+        Gets or sets allows to specify metafile rendering options.  # noqa: E501
 
         :param metafile_rendering_options: The metafile_rendering_options of this XpsSaveOptionsData.  # noqa: E501
         :type: MetafileRenderingOptionsData
         """
         self._metafile_rendering_options = metafile_rendering_options
+
     @property
     def numeral_format(self):
         """Gets the numeral_format of this XpsSaveOptionsData.  # noqa: E501
@@ -241,6 +472,7 @@ class XpsSaveOptionsData(object):
         :type: str
         """
         self._numeral_format = numeral_format
+
     @property
     def optimize_output(self):
         """Gets the optimize_output of this XpsSaveOptionsData.  # noqa: E501
@@ -262,6 +494,7 @@ class XpsSaveOptionsData(object):
         :type: bool
         """
         self._optimize_output = optimize_output
+
     @property
     def page_count(self):
         """Gets the page_count of this XpsSaveOptionsData.  # noqa: E501
@@ -283,6 +516,7 @@ class XpsSaveOptionsData(object):
         :type: int
         """
         self._page_count = page_count
+
     @property
     def page_index(self):
         """Gets the page_index of this XpsSaveOptionsData.  # noqa: E501
@@ -304,224 +538,7 @@ class XpsSaveOptionsData(object):
         :type: int
         """
         self._page_index = page_index
-    @property
-    def save_format(self):
-        """Gets the save_format of this XpsSaveOptionsData.  # noqa: E501
 
-        Gets or sets format of save.  # noqa: E501
-
-        :return: The save_format of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._save_format
-
-    @save_format.setter
-    def save_format(self, save_format):
-        """Sets the save_format of this XpsSaveOptionsData.
-
-        Gets or sets format of save.  # noqa: E501
-
-        :param save_format: The save_format of this XpsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._save_format = save_format
-    @property
-    def file_name(self):
-        """Gets the file_name of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets name of destination file.  # noqa: E501
-
-        :return: The file_name of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._file_name
-
-    @file_name.setter
-    def file_name(self, file_name):
-        """Sets the file_name of this XpsSaveOptionsData.
-
-        Gets or sets name of destination file.  # noqa: E501
-
-        :param file_name: The file_name of this XpsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._file_name = file_name
-    @property
-    def dml_rendering_mode(self):
-        """Gets the dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :return: The dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_rendering_mode
-
-    @dml_rendering_mode.setter
-    def dml_rendering_mode(self, dml_rendering_mode):
-        """Sets the dml_rendering_mode of this XpsSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501
-
-        :param dml_rendering_mode: The dml_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_rendering_mode = dml_rendering_mode
-    @property
-    def dml_effects_rendering_mode(self):
-        """Gets the dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :return: The dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml_effects_rendering_mode
-
-    @dml_effects_rendering_mode.setter
-    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
-        """Sets the dml_effects_rendering_mode of this XpsSaveOptionsData.
-
-        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501
-
-        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
-    @property
-    def zip_output(self):
-        """Gets the zip_output of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :return: The zip_output of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._zip_output
-
-    @zip_output.setter
-    def zip_output(self, zip_output):
-        """Sets the zip_output of this XpsSaveOptionsData.
-
-        Gets or sets controls zip output or not. Default value is false.  # noqa: E501
-
-        :param zip_output: The zip_output of this XpsSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._zip_output = zip_output
-    @property
-    def update_last_saved_time_property(self):
-        """Gets the update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :return: The update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_last_saved_time_property
-
-    @update_last_saved_time_property.setter
-    def update_last_saved_time_property(self, update_last_saved_time_property):
-        """Sets the update_last_saved_time_property of this XpsSaveOptionsData.
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501
-
-        :param update_last_saved_time_property: The update_last_saved_time_property of this XpsSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_last_saved_time_property = update_last_saved_time_property
-    @property
-    def update_sdt_content(self):
-        """Gets the update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :return: The update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_sdt_content
-
-    @update_sdt_content.setter
-    def update_sdt_content(self, update_sdt_content):
-        """Sets the update_sdt_content of this XpsSaveOptionsData.
-
-        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501
-
-        :param update_sdt_content: The update_sdt_content of this XpsSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_sdt_content = update_sdt_content
-    @property
-    def update_fields(self):
-        """Gets the update_fields of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
-
-        :return: The update_fields of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_fields
-
-    @update_fields.setter
-    def update_fields(self, update_fields):
-        """Sets the update_fields of this XpsSaveOptionsData.
-
-        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true  # noqa: E501
-
-        :param update_fields: The update_fields of this XpsSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_fields = update_fields
-    @property
-    def dml3_d_effects_rendering_mode(self):
-        """Gets the dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :return: The dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._dml3_d_effects_rendering_mode
-
-    @dml3_d_effects_rendering_mode.setter
-    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
-        """Sets the dml3_d_effects_rendering_mode of this XpsSaveOptionsData.
-
-        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
-
-        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this XpsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        allowed_values = ["Basic", "Advanced"]  # noqa: E501
-        if not dml3_d_effects_rendering_mode.isdigit():	
-            if dml3_d_effects_rendering_mode not in allowed_values:
-                raise ValueError(
-                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
-                    .format(dml3_d_effects_rendering_mode, allowed_values))
-            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
-        else:
-            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
-    @property
-    def update_last_printed_property(self):
-        """Gets the update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
-
-        :return: The update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
-        :rtype: bool
-        """
-        return self._update_last_printed_property
-
-    @update_last_printed_property.setter
-    def update_last_printed_property(self, update_last_printed_property):
-        """Sets the update_last_printed_property of this XpsSaveOptionsData.
-
-        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
-
-        :param update_last_printed_property: The update_last_printed_property of this XpsSaveOptionsData.  # noqa: E501
-        :type: bool
-        """
-        self._update_last_printed_property = update_last_printed_property
     @property
     def bookmarks_outline_level(self):
         """Gets the bookmarks_outline_level of this XpsSaveOptionsData.  # noqa: E501
@@ -543,6 +560,7 @@ class XpsSaveOptionsData(object):
         :type: int
         """
         self._bookmarks_outline_level = bookmarks_outline_level
+
     @property
     def headings_outline_levels(self):
         """Gets the headings_outline_levels of this XpsSaveOptionsData.  # noqa: E501
@@ -564,11 +582,12 @@ class XpsSaveOptionsData(object):
         :type: int
         """
         self._headings_outline_levels = headings_outline_levels
+
     @property
     def outline_options(self):
         """Gets the outline_options of this XpsSaveOptionsData.  # noqa: E501
 
-        Gets or sets outline_options.  # noqa: E501
+        Gets or sets allows to specify outline options.  # noqa: E501
 
         :return: The outline_options of this XpsSaveOptionsData.  # noqa: E501
         :rtype: OutlineOptionsData
@@ -579,12 +598,13 @@ class XpsSaveOptionsData(object):
     def outline_options(self, outline_options):
         """Sets the outline_options of this XpsSaveOptionsData.
 
-        Gets or sets outline_options.  # noqa: E501
+        Gets or sets allows to specify outline options.  # noqa: E501
 
         :param outline_options: The outline_options of this XpsSaveOptionsData.  # noqa: E501
         :type: OutlineOptionsData
         """
         self._outline_options = outline_options
+
     @property
     def use_book_fold_printing_settings(self):
         """Gets the use_book_fold_printing_settings of this XpsSaveOptionsData.  # noqa: E501
@@ -606,6 +626,8 @@ class XpsSaveOptionsData(object):
         :type: bool
         """
         self._use_book_fold_printing_settings = use_book_fold_printing_settings
+
+
     def to_dict(self):
         """Returns the model properties as a dict"""
         result = {}
@@ -647,4 +669,4 @@ class XpsSaveOptionsData(object):
 
     def __ne__(self, other):
         """Returns true if both objects are not equal"""
-        return not self == other
+        return not self == other
\ No newline at end of file
